<?php
/**
 * Loads the Evergreen Content Poster configuration wizard.
 *
 * @link       https://www.evergreencontentposter.com/
 * @since      1.2.0
 * @package    Evergreen_Content_Poster
 * @subpackage Evergreen_Content_Poster/Configuration_Page
 * @author     evergreencontentposter <support@evergreencontentposter.com>
 */

class Evergreen_Content_Poster_Content_Configuration_Page
{
   /**
    * The ID of this plugin.
    *
    * @since    1.0.0
    * @access   private
    * @var      string    $plugin_name    The ID of this plugin.
    */
   private $plugin_name;

   /**
    * The version of this plugin.
    *
    * @since    1.0.0
    * @access   private
    * @var      string    $version    The current version of this plugin.
    */
   private $version;

   /**
    * Initialize the class and set its properties.
    *
    *
    * @since 1.2.0
    * Evergreen_Content_Poster_Configuration_Page constructor.
    * @param Evergreen_Content_Poster_Configuration_Page
    */
   private $buffer;
   private $settings;
   private $common;
   private $twitter;
   private $buffer_settings;

   /**
    * Initialize the class and set its properties.
    *
    * @since    1.0.0
    */
   public function __construct(
      Evergreen_Content_Poster_Buffer $buffer,
      Evergreen_Content_Poster_Settings $setting_buffer,
      Evergreen_Content_Poster_Common $common,
      Evergreen_Content_Poster_Twitter $twitter
   ) {
      $this->buffer = $buffer;
      $this->settings = $setting_buffer;
      $this->common = $common;
      $this->twitter = $twitter;
      $this->buffer_settings = $this->common->general_settings();

      add_action('wp_ajax_ajaxStepCompleted', [$this, 'ajaxStepCompleted']);
      add_action('wp_ajax_ajaxStep5Save', [$this, 'ajaxStep5Save']);
      add_action('wp_ajax_ajaxSaveContact', [$this, 'ajaxSaveContact']);
      add_action('wp_ajax_updateCategoryStep', [$this, 'updateCategoryStep']);
      add_action('wp_ajax_addCategoryStep', [$this, 'addCategoryStep']);
      add_action('wp_ajax_deleteCategoryStep', [$this, 'deleteCategoryStep']);
      add_action('wp_ajax_finishOnboard', [$this, 'finishOnboard']);
   }

   /**
    * update complete onboard config
    *
    * @return void
    * @since 1.3.0
    */
   public function finishOnboard(): void
   {
      $userId = get_current_user_id();
      if (get_user_meta($userId, 'ecp-getting-started-dismissed')) {
         update_user_meta($userId, 'ecp-getting-started-dismissed', 'true', true);
      } else {
         add_user_meta($userId, 'ecp-getting-started-dismissed', 'true', true);
      }

      wp_send_json_success();
   }

   /**
    * Enqueues the assets needed for the configurator.
    */
   public function enqueue_assets(): void
   {
      wp_enqueue_media();
      /*
      * Print the `forms.css` WP stylesheet before any Evergreen Content Poster style, this way
      * it's easier to override selectors with the same specificity later.
      */
      wp_enqueue_style('forms');
   }

   /**
    * Update step to ecp_options
    */
   public function ajaxStepCompleted(): void
   {
      $options = get_option('ecp_options');

      $step = absint($_POST['step']);
      if ($step && (!isset($options['onboarding_step']) || $step > $options['onboarding_step'])) {
         $options['onboarding_step'] = $step;
         update_option('ecp_options', $options);
      }

      wp_send_json_success($step);
   }

   /**
    * Update category by Step
    */
   public function updateCategoryStep(): void
   {
      global $wpdb;

      $id = absint($_POST['cate_id']);
      $name = sanitize_text_field($_POST['cate_name']);
      $des = sanitize_text_field($_POST['cate_des']);
      $random = absint($_POST['random_availability']);

      // Update category
      if ($id) {
         $wpdb->update($wpdb->prefix . 'evergreen_categories', ['name' => $name, 'description' => $des, 'random_availability' => $random, 'updated_at' => date('Y-m-d H:i:s')], ['id' => $id]);
      }

      wp_send_json_success($id);
   }

   /**
    * Add category by Step
    */
   public function addCategoryStep(): void
   {
      global $wpdb;

      $name = sanitize_text_field($_POST['cate_name']);
      $des = sanitize_text_field($_POST['cate_des']);
      $random = absint($_POST['random_availability']);

      // Add category
      $wpdb->insert($wpdb->prefix . 'evergreen_categories', ['name' => $name, 'description' => $des, 'random_availability' => $random, 'created_at' => date('Y-m-d H:i:s')]);

      wp_send_json_success($wpdb->insert_id);
   }

   /**
    * Delete category by step
    */
   public function deleteCategoryStep(): void
   {
      global $wpdb;

      $category_id = absint($_POST['cate_id']);

      // Check if the category exists in the database
      $category = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}evergreen_categories WHERE id = ${category_id}");
      if (empty((array) $category)) {
         wp_send_json_error([
            'message' => __('The category doesn\'t exist', 'evergreen-content-poster'),
            'error' => 0,
         ]);
      } else {
         // Get all posts in category
         $strSql = "SELECT p.* FROM {$wpdb->prefix}posts p JOIN {$wpdb->prefix}postmeta pm ON pm.post_id = p.ID WHERE pm.meta_key = 'ecp-post-category' AND meta_value = " . $category_id . " AND p.post_type = 'ecp-posts'";

         $posts = $wpdb->get_results($strSql);

         foreach ($posts as $post) {
            wp_delete_post($post->ID, true);

            $wpdb->delete($wpdb->prefix . 'postmeta', ['post_id' => $post->ID]);
         } // end foreach ($posts as $post)

         // Delete schedule
         $schedules_setting = get_option('ecp_schedule_settings');
         if (!empty($schedules_setting)) {
            $schedules = $schedules_setting['schedules'];

            $this->deleteSchedule($category_id, $schedules);
         }

         $wpdb->delete($wpdb->prefix . 'evergreen_categories', ['id' => $category_id]);
         wp_send_json_success([
            'timestamp' => current_time('timestamp'),
            'category_id' => $category_id,
            'message' => __('Success', 'evergreen-content-poster'),
            'error' => 200,
         ]);
      }
   }

   /**
    * Delete schedule by category id and schedules
    *
    * @param $category_id
    * @param $schedules
    */
   public function deleteSchedule($category_id, $schedules): void
   {
      if (!empty($schedules)) {
         foreach ($schedules as $service => $schedule) {
            foreach ($schedule as $profileId => $single_schedule) {
               foreach ($single_schedule as $k => $std) {
                  $times = [];
                  foreach ($std->times as $time) {
                     if ($time['category_id'] !== $category_id) {
                        $times[] = $time;
                     }
                  } // end foreach ($std->times as $time

                  $schedules[$service][$profileId][$k]->times = $times;
               } // end foreach ($single_schedule as $k => $std)
            } // end foreach ($schedule as $profileId => $single_schedule)
         } // end foreach ($schedules as $service => $schedule) {

         $schedules_setting['schedules'] = $schedules;

         update_option('ecp_schedule_settings', $schedules_setting, true);
      }
   }

   /**
    * Save setup in step 5
    */
   public function ajaxStep5Save(): void
   {
      $options = get_option('ecp_options');

      $options['step5']['business_type'] = sanitize_text_field($_POST['type_business_value']);
      $options['step5']['business_type_detail'] = sanitize_text_field($_POST['type_entrepreneur_value']);
      $options['step5']['business_industry'] = htmlentities(sanitize_text_field($_POST['industry']));

      update_option('ecp_options', $options);

      // update db api
      $token = evergreenGetStatisticsToken();
      $data['sites'] = [
         'url' => home_url(),
         'token' => $token,
         'business_type' => sanitize_text_field($_POST['type_business_value']),
         'business_type_detail' => sanitize_text_field($_POST['type_entrepreneur_value']),
         'business_industry' => sanitize_text_field($_POST['industry']),
         'plugin_name' => 'evergreen content poster',
      ];

      updateApiStatistics($data);

      $result = [
         'code' => 200,
         'message' => 'OK',
      ];

      wp_send_json_success($result);
   }

   /**
    * Update subscriber email
    */
   public function ajaxSaveContact(): void
   {
      $email = sanitize_email($_POST['email']);
      // update db api
      $token = evergreenGetStatisticsToken();
      $data['sites'] = [
         'url' => home_url(),
         'token' => $token,
         'contact_email' => $email,
         'plugin_name' => 'evergreen content poster',
      ];

      updateApiStatistics($data);

      //update options
      $ecp_options = get_option('ecp_options');
      $ecp_options['contact_email'] = $email;

      update_option('ecp_options', $ecp_options);

      wp_send_json_success($email);
   }

   /**
    * Load page
    */
   public function load_page(): void
   {
      global $wpdb, $statistics;

      $token = $this->buffer->get_token();
      $twitterToken = $this->twitter->get_token();
      $profiles = $this->buffer->profiles();
      $settings = $this->common->general_settings();
      $schedule_settings = $this->common->schedules();
      $schedules = $schedule_settings['schedules'] ?? null;

      $allCategories = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}evergreen_categories");
      $allCategoriesName = [];
      foreach ($allCategories as $category) {
         $allCategoriesName[$category->id] = $category->name;
      } // end foreach ($allCategories as $category) {

      $ecp_frequency_schedules = get_option('ecp_frequency_schedules');

      $selected_profile = new stdClass();

      $scheduleDefineLast = $this->settings->getScheduleDefine($schedules, $profiles);

      $categories = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}evergreen_categories WHERE status = 1");

      $categoryIds = [];

      foreach ($categories as $category) {
         $categoryIds[] = $category->id;
      } // end foreach ($categories as $category)

      $statistics = $this->settings->get_statistics($allCategories, $scheduleDefineLast, $profiles);

      $totalNum = $this->settings->getTotalStatistics($statistics['total']);

      $this->enqueue_assets();
      $dashboard_url = admin_url('/admin.php?page=evergreen-content-settings');

      $options = get_option('ecp_options');
      $step_completed = 0;
      if (isset($options['onboarding_step'])) {
         $step_completed = $options['onboarding_step'];
      }
      $step5 = [
         'business_type' => '',
         'business_type_detail' => '',
         'business_industry' => '',
      ];
      if (isset($options['step5'])) {
         $step5 = $options['step5'];
      } ?>

      <div class="ecp-grid ecp-col-940 ecp-top-menu ecp-configurator" ecp-registered="1">
         <div class="ecp-grid ecp-col-540 ecp-configurator-container ecp-configurator-content ecp-box-border"></div>
         <div class="ecp-header-wrapper">
            <div class="ecp-grid ecp-col-540 header-box">
               <div class="ecp-header-logo"></div>
               <p class="ecp-configurator-subtitle"><?php _e('Installation wizard', 'evergreen-content-poster'); ?></p>
            </div>
            <div class="ecp-grid-right ecp-col-220 ecp-fit">
               <?php wp_nonce_field('evergreen-settings-save', 'evergreen-settings-save'); ?>
               <a href="<?php echo $dashboard_url; ?>" class="button ecp-grey-button ecp-close-wizard"><?php _e('close the wizard', 'evergreen-content-poster'); ?></a>
            </div>
            <div class="ecp-clearfix"></div>
            <div class="ecp-grid ecp-col-540 ecp-configurator-container">
               <nav class="ecp-wizard-stepper">
                  <div class="ecp-box">
                     <div class="ecp-item <?php if ($step_completed >= 1) { ?> completed <?php } ?>" id="navstep-1">
                        <button class="ecp-wizard--step ecp-wizard--step__active" aria-label="<?php _e('Step 1:', 'evergreen-content-poster'); ?> <?php _e('Social accounts', 'evergreen-content-poster'); ?>" aria-current="step" tabindex="0" type="button">
                           <svg viewBox="0 0 24 24" style="display: block; height: 24px; width: 24px; user-select: none; transition: all 450ms cubic-bezier(0.23, 1, 0.32, 1) 0ms; font-size: 24px;">
                              <circle cx="12" cy="12" r="10"></circle>
                              <text x="12" y="16" text-anchor="middle" font-size="12" fill="#fff"><?php if ($step_completed >= 1) { ?> &check; <?php } else { ?> 1 <?php } ?></text>
                           </svg>
                        </button>
                        <div class="step-des-box">
                           <p><?php _e('Step 1:', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Setting up your social accounts', 'evergreen-content-poster'); ?></p>
                        </div>
                     </div>

                     <div class="ecp-item <?php if ($step_completed >= 2) { ?> completed <?php } ?>" id="navstep-2">
                        <button class="ecp-wizard--step ecp-wizard--step__inactive" aria-label="<?php _e('Step 2:', 'evergreen-content-poster'); ?> <?php _e('Content categories', 'evergreen-content-poster'); ?>" tabindex="0" type="button">
                           <svg viewBox="0 0 24 24" style="display: block; height: 24px; width: 24px; user-select: none; transition: all 450ms cubic-bezier(0.23, 1, 0.32, 1) 0ms; font-size: 24px;">
                              <circle cx="12" cy="12" r="10"></circle>
                              <text x="12" y="16" text-anchor="middle" font-size="12" fill="#fff"><?php if ($step_completed >= 2) { ?> &check; <?php } else { ?> 2 <?php } ?></text>
                           </svg>
                        </button>
                        <div class="step-des-box">
                           <p><?php _e('Step 2:', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Setting up your content categories', 'evergreen-content-poster'); ?></p>
                        </div>
                     </div>

                     <div class="ecp-item <?php if ($step_completed >= 3) { ?> completed <?php } ?>" id="navstep-3">
                        <button class="ecp-wizard--step ecp-wizard--step__inactive" aria-label="<?php _e('Step 3:', 'evergreen-content-poster'); ?> <?php _e('Create schedule', 'evergreen-content-poster'); ?>" tabindex="0" type="button">

                           <svg viewBox="0 0 24 24" style="display: inline-block; height: 24px; width: 24px; user-select: none; transition: all 450ms cubic-bezier(0.23, 1, 0.32, 1) 0ms;">
                              <circle cx="12" cy="12" r="10"></circle>
                              <text x="12" y="16" text-anchor="middle" font-size="12" fill="#fff"><?php if ($step_completed >= 3) { ?> &check; <?php } else { ?> 3 <?php } ?></text>
                           </svg>
                        </button>
                        <div class="step-des-box">
                           <p><?php _e('Step 3:', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Creating your posting schedule', 'evergreen-content-poster'); ?></p>
                        </div>
                     </div>

                     <div class="ecp-item <?php if ($step_completed >= 4) { ?> completed <?php } ?>" id="navstep-4">
                        <button class="ecp-wizard--step ecp-wizard--step__inactive" aria-label="<?php _e('Step 4:', 'evergreen-content-poster'); ?> <?php _e('Create content', 'evergreen-content-poster'); ?>" tabindex="0" type="button">
                           <svg viewBox="0 0 24 24" style="display: inline-block; height: 24px; width: 24px; user-select: none; transition: all 450ms cubic-bezier(0.23, 1, 0.32, 1) 0ms;">
                              <circle cx="12" cy="12" r="10"></circle>
                              <text x="12" y="16" text-anchor="middle" font-size="12" fill="#fff"><?php if ($step_completed >= 4) { ?> &check; <?php } else { ?> 4 <?php } ?></text>
                           </svg>
                        </button>
                        <div class="step-des-box">
                           <p><?php _e('Step 4:', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Creating your first content', 'evergreen-content-poster'); ?></p>
                        </div>
                     </div>

                     <div class="ecp-item <?php if ($step_completed >= 5) { ?> completed <?php } ?>" id="navstep-5">
                        <button class="ecp-wizard--step ecp-wizard--step__inactive" aria-label="<?php _e('Step 5:', 'evergreen-content-poster'); ?> <?php _e('Optional: business type', 'evergreen-content-poster'); ?>" tabindex="0" type="button">
                           <svg viewBox="0 0 24 24" style="display: inline-block; height: 24px; width: 24px; user-select: none; transition: all 450ms cubic-bezier(0.23, 1, 0.32, 1) 0ms;">
                              <circle cx="12" cy="12" r="10"></circle>
                              <text x="12" y="16" text-anchor="middle" font-size="12" fill="#fff"><?php if ($step_completed >= 5) { ?> &check; <?php } else { ?> 5 <?php } ?></text>
                           </svg>
                        </button>
                        <div class="step-des-box">
                           <p><?php _e('Step 5:', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Optional: Let us know your business type', 'evergreen-content-poster'); ?></p>
                        </div>
                     </div>

                     <div class="ecp-item <?php if ($step_completed >= 6) { ?> completed <?php } ?>" id="navstep-6">
                        <button class="ecp-wizard--step ecp-wizard--step__inactive" aria-label="<?php _e('Step 6:', 'evergreen-content-poster'); ?> <?php _e('Optional: Newsletter', 'evergreen-content-poster'); ?>" tabindex="0" type="button">
                           <svg viewBox="0 0 24 24" style="display: inline-block; height: 24px; width: 24px; user-select: none; transition: all 450ms cubic-bezier(0.23, 1, 0.32, 1) 0ms;">
                              <circle cx="12" cy="12" r="10"></circle>
                              <text x="12" y="16" text-anchor="middle" font-size="12" fill="#fff"><?php if ($step_completed >= 6) { ?> &check; <?php } else { ?> 6 <?php } ?></text>
                           </svg>
                        </button>
                        <div class="step-des-box">
                           <p><?php _e('Step 6:', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Optional: Subscribe to our newsletter', 'evergreen-content-poster'); ?></p>
                        </div>
                     </div>

                     <div class="ecp-item <?php if ($step_completed >= 7) { ?> completed <?php } ?>" id="navstep-7">
                        <button class="ecp-wizard--step ecp-wizard--step__inactive" aria-label="<?php _e('Step 7:', 'evergreen-content-poster'); ?> <?php _e('Success!', 'evergreen-content-poster'); ?>" tabindex="0" type="button">
                           <svg viewBox="0 0 24 24" style="display: inline-block; height: 24px; width: 24px; user-select: none; transition: all 450ms cubic-bezier(0.23, 1, 0.32, 1) 0ms;">
                              <circle cx="12" cy="12" r="10"></circle>
                              <text x="12" y="16" text-anchor="middle" font-size="12" fill="#fff"><?php if ($step_completed >= 7) { ?> &check; <?php } else { ?> 7 <?php } ?></text>
                           </svg>
                        </button>
                        <div class="step-des-box">
                           <p><?php _e('Step 7:', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Success! You\'re ready to start sharing', 'evergreen-content-poster'); ?></p>
                        </div>
                     </div>
                  </div>
               </nav>
            </div>
         </div>
      </div>

      <div class="ecp-wrapper">
         <label class="hidden saving-default"><?php _e('Saving Settings', 'evergreen-content-poster'); ?></label>
         <label class="hidden saving-success"><?php _e('Settings Saved!', 'evergreen-content-poster'); ?></label>
         <label class="hidden saving-error"><?php _e('There was an error saving your settings. Please try again later.', 'evergreen-content-poster'); ?></label>
         <div class="ecp-container">
            <div class="ecp-section">
               <div class="ecp-grid ecp-col-540 ecp-configurator-container ecp-configurator-content">
                  <div class="ecp-wizard ecp-section ecp-grid ecp-col-940 ecp-fit ecp-no-bottom-margin">
                     <div id="step-1" class="active step-content">
                        <h2 style="text-align: center;"><?php _e('Welcome to the Evergreen Content Poster &#128640; &#127881;', 'evergreen-content-poster'); ?></h2>
                        <p><?php echo sprintf(__('Thank you for installing and using the Evergreen Content Poster v%s.', 'evergreen-content-poster'), EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION) ?></p>
                        <p><?php _e('This plugin will allow you to easily double your traffic from social media by keeping your content alive and in front of the audiences that matter.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('But before we can do that, we first need to run a little setup, so we know to which social networks we need to share your content and at what time.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('Let\'s <strong><em>start by connecting your social media accounts</em></strong>.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('<em>Note: At the moment, we only support posting to social media via a (free) Buffer account. But more native networks will be added in the future.</em>', 'evergreen-content-poster'); ?></p>
                        <div class="ecp-social-networks-title-wrapper">
                           <div class="ecp-grid ecp-col-220 ecp-no-bottom-margin ecp-linked">
                              <?php if (!$token) { ?>
                                 <a href="<?php echo $this->buffer->oauth_url_config(); ?>" class="button ecp-buffer-button ecp-save-settings linked-button"><svg version="1.1" id="buffer-logo" style="padding-right: 5px" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="12px" viewBox="0 0 32 36" style="enable-background:new 0 0 32 36;" xml:space="preserve">
                                       <path class="st0" d="M0.7,8.6l15.4-8l15.6,8l-15.6,8L0.7,8.6z M5.6,15.6l10.5,5.2l10.6-5.2l5,2.4l-15.6,7.6L0.7,18L5.6,15.6z M5.6,24.6l10.5,5.7l10.6-5.7l5,2.6l-15.6,8.4L0.7,27.3L5.6,24.6z" />
                                    </svg><span class="text ecp-connect-to-buffer"><?php _e('Connect to Buffer', 'evergreen-content-poster'); ?></span></a>
                              <?php } else { ?>
                                 <a href="<?php echo $this->buffer->deauthorize_url($_REQUEST['page']); ?>" class="button ecp-green-button ecp-save-settings linked-button buffer-connected" data-connected="<?php _e('Connected to Buffer', 'evergreen-content-poster'); ?>" data-disconnect="<?php _e('Disconnect from Buffer', 'evergreen-content-poster'); ?>"><svg version="1.1" id="buffer-logo" style="padding-right: 5px" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="12px" viewBox="0 0 32 36" style="enable-background:new 0 0 32 36;" xml:space="preserve">
                                       <path class="st0" d="M0.7,8.6l15.4-8l15.6,8l-15.6,8L0.7,8.6z M5.6,15.6l10.5,5.2l10.6-5.2l5,2.4l-15.6,7.6L0.7,18L5.6,15.6z M5.6,24.6l10.5,5.7l10.6-5.7l5,2.6l-15.6,8.4L0.7,27.3L5.6,24.6z" />
                                    </svg><span class="text ecp-connect-to-buffer"><?php _e('Connected to Buffer', 'evergreen-content-poster'); ?></span></a>
                              <?php } ?>
                           </div>
                           <div class="ecp-grid ecp-col-220 ecp-no-bottom-margin ecp-linked">
                                 <?php if (!$twitterToken) { ?>
                                       <a href="<?php echo $this->twitter->twitter_oauth_url_config(); ?>" class="button ecp-twitter-button ecp-save-settings linked-button"><span class="dashicons dashicons-twitter" style="padding-right: 5px;"></span><span class="text ecp-connect-to-twitter"><?php _e('Connect to Twitter', 'evergreen-content-poster'); ?></span></a>
                                 <?php } else { ?>
                                       <a href="<?php echo $this->twitter->deauthorize_url($_REQUEST['page']); ?>" class="button ecp-green-button ecp-save-settings linked-button twitter-connected" data-connected="<?php _e('Connected to Twitter', 'evergreen-content-poster'); ?>" data-disconnect="<?php _e('Disconnect from Twitter', 'evergreen-content-poster'); ?>"><span class="dashicons dashicons-twitter" style="padding-right: 5px;"></span><span class="text ecp-connect-to-twitter"><?php _e('Connected to Twitter', 'evergreen-content-poster'); ?></span></a>
                                 <?php } ?>
                           </div>
                        </div>
                        <div class="ecp-clearfix"></div>

                        <div class="ecp-section ecp-grid ecp-col-620 ecp-fit ecp-option-container">
                           <?php if ( $token && $twitterToken ) { ?>
                                    <p><?php _e("We've successfully connected both your Buffer and Twitter accounts to the following profiles.", 'evergreen-content-poster'); ?> </p>
                               <?php } else if($twitterToken) { ?>
                                    <p><?php _e('Your Twitter account is successfully connected. If you want, you can add an additional Buffer account by clicking the "Connect to Buffer" button above.', 'evergreen-content-poster'); ?> </p>
                                <?php } else if ( $token ) { ?>
                                    <p><?php _e('Your Buffer account is successfully connected. If you want, you can add an additional (natively connected) Twitter account by clicking the "Connect to Twitter" button above.', 'evergreen-content-poster'); ?> </p>
                                <?php } else { ?>
                                <p><?php _e('You need to connect a social media account.', 'evergreen-content-poster'); ?> <?php _e('If you want to start using the Evergreen Content Poster, use the "Connect to Buffer" button above to sign in and connect your Buffer account to the plugin.', 'evergreen-content-poster'); ?></p>
                                <?php } ?>
                           <p>
                              <?php echo sprintf(
                                 /* translators: %1$s is a link start tag to Buffer signup page, %2$s is the link closing tag */
                                 __('If you don\'t have a <strong>Buffer</strong> account yet, you can create a %1sfree Buffer account here%2s.', 'evergreen-content-poster'),
                                 '<a href="https://buffer.com/signup" target="_blank" class="ecp-link">',
                                 '</a>'
                              ); ?><br />
                              <?php echo sprintf(
                                 /* translators: %1$s is a link start tag to Buffer signup page, %2$s is the link closing tag */
                                 __('Additionally, if you don\'t have a <strong>Twitter</strong> account yet, you can create a %1sfree Twitter account here%2s.', 'evergreen-content-poster'),
                                 '<a href="https://twitter.com/" target="_blank" class="ecp-link">',
                                 '</a>'
                              ); ?>
                           </p>
                        </div>

                        <?php if ($token) { ?>
                           <?php if (!empty($profiles)) { ?>
                              <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                 <h2><?php _e('Connected Social Profiles', 'evergreen-content-poster'); ?></h2>
                              </div>
                              <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                 <?php foreach ($profiles as $service => $profile_list) { ?>
                                    <?php
                                    foreach ($profile_list as $key => $single_profile) {
                                       $avatar = EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png';
                                       if (!empty($single_profile->avatar)) {
                                          $avatar = $single_profile->avatar;
                                       }

                                       $profile_username = !empty($single_profile->formatted_username) ? $single_profile->formatted_username : ucwords($single_profile->service_type) . ($key + 1);
                                       if (strlen($profile_username) > 18) {
                                          $profile_username = substr($profile_username, 0, 15) . '...';
                                       }

                                       $service_type = $single_profile->service . ' ' . ucwords($single_profile->service_type);
                                       if (strlen($service_type) > 17) {
                                          $service_type = substr($service_type, 0, 14) . '...';
                                       }

                                       $cssClass = '';
                                       if (isset($_REQUEST['ecp_profile']) && $single_profile->id === sanitize_text_field($_REQUEST['ecp_profile'])) {
                                          $cssClass = 'active';

                                          $selected_profile = $single_profile;
                                          $selected_schedules = $schedules[$single_profile->service][$single_profile->id];
                                       }
                                    ?>
                                       <div class="ecp-grid ecp-col-200">
                                          <a href="<?php echo get_bloginfo('wpurl'); ?>/wp-admin/admin.php?page=evergreen-content-settings&ecp_profile=<?php echo $single_profile->id; ?>&edit_schedule=Y#connected_profiles" class="ecp-profile-select">
                                             <div class="ecp-connected-profile <?php echo $cssClass; ?>">
                                                <div class="ecp-connected-profile-avatar">
                                                   <img class="ecp-profile-circle" ng-src="<?php echo $avatar; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $avatar; ?>">
                                                   <div class="ecp-social-network-icon ecp-<?php echo strtolower($single_profile->service); ?>"></div>
                                                </div>
                                                <div class="ecp-connected-profile-name">
                                                   <span class="ecp-connected-profile-username"><?php _e($profile_username, 'evergreen-content-poster'); ?></span>
                                                   <br />
                                                   <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                </div>
                                             </div>
                                          </a>
                                       </div>
                                    <?php } // end foreach ($profile_list as $key => $single_profile)
                                    ?>
                                 <?php } // end foreach ($profiles as $service => $profile_list)
                                 ?>
                              </div>
                           <?php } else { ?>
                              <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                 <div class="ecp-grid ecp-col-300">
                                    <p><strong><?php _e('No profiles added to Buffer yet...', 'evergreen-content-poster'); ?></strong></p>
                                    <p><?php echo sprintf(
                                          /* translators: %1$s is a link start tag to the Buffer account connection page, %2$s is the link closing tag */
                                          esc_html__('%1sAdd at least one profile to your Buffer account%2s, to start using the Evergreen Content Poster.', 'evergreen-content-poster'),
                                          '<a href="https://account.buffer.com/channels/connect/" target="_blank" class="ecp-link">',
                                          '</a>'
                                       ); ?></p>
                                    <p><em><?php _e('Note: After you\'ve added one or more accounts to your Buffer account, you need to disconnect and connect your Buffer account again to the Evergreen Content Poster.', 'evergreen-content-poster'); ?></em></p>
                                 </div>
                              </div>
                           <?php } ?>
                        <?php } ?>

                        <div class="ecp-clearfix"></div>
                        <div class="ecp-grid-right">
                           <a href="#" class="button ecp-green-button ecp-next" data-step="1" style="color:#1b3a51; font-weight: 600" <?php if (!$token) { ?> disabled="true" <?php } ?>><?php _e('next', 'evergreen-content-poster'); ?></a>
                        </div>
                     </div> <!-- end step 1 -->

                     <!-- step 2 -->
                     <div id="step-2" class="step-content">
                        <h2 style="text-align: center;"><?php _e('Step 2:', 'evergreen-content-poster'); ?> <?php _e('Your content categories', 'evergreen-content-poster'); ?></h2>
                        <p><?php _e('Now that your social media accounts are connected, let\'s start by creating content categories.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('Because while content is king, you don\'t want to bore your followers with only the same types of content over and over again.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('You do this by <strong><em>creating a healthy and diverse mix of content.</em></strong>', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('Different categories can have different content schedules, which we will get to in the next step.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('Use the preset categories below to get a start on your content mix:', 'evergreen-content-poster'); ?></p>

                        <div class="categories-box">
                           <?php
                           $allCategories = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}evergreen_categories");

                           if (count($allCategories) > 0) {
                              foreach ($allCategories as $category) {
                           ?>
                                 <div class="ecp-grid ecp-col-220 ecp-content-border" id="cat-<?php echo $category->id ?>">
                                    <h3 class="ecp-category-title"><?php echo $category->name ?></h3>
                                    <p class="ecp-category-description">
                                       <?php echo wp_unslash($category->description) ?>
                                    </p>
                                    <div class="ecp-edit-button">
                                       <div class="ecp-inline-block">
                                          <a data-random="<?php echo $category->random_availability ?>" data-id="<?php echo $category->id ?>" href="#edit-category" rel="modal:open" class="button ecp-grey-button ecp-edit ecp-category-edit-button" style="color:#646970; float: none; padding: 10px 15px;"><?php _e('edit', 'evergreen-content-poster'); ?></a>
                                       </div>
                                       <?php if (!$category->is_default) { ?>
                                          <div class="ecp-inline-block">
                                             <a data-id="<?php echo $category->id ?>" href="#delete-category" rel="modal:open" class="button ecp-grey-button ecp-delete ecp-delete-button" style="color:#646970; float: none; padding: 10px 15px;">
                                                <?php _e('delete', 'evergreen-content-poster'); ?>
                                             </a>
                                          </div>
                                       <?php } ?>
                                    </div>
                                 </div>
                           <?php
                              } // end foreach ($allCategories as $category)
                           } ?>
                        </div>

                        <div class="ecp-grid ecp-col-220 ecp-content-border ecp-category-template ecp-hidden" id="">
                           <h3 class="ecp-category-title"></h3>
                           <p class="ecp-category-description"></p>
                           <div class="ecp-grid ecp-col-220">
                              <a data-random="" data-id="" href="#edit-category" rel="modal:open" class="button ecp-grey-button ecp-edit ecp-category-edit-button" style="color:#646970; float: none; padding: 10px 15px;"><?php _e('edit', 'evergreen-content-poster'); ?></a>
                           </div>
                           <div class="ecp-grid ecp-col-220"></div>
                           <div class="ecp-grid ecp-col-220">
                              <a data-id="" href="#delete-category" rel="modal:open" class="button ecp-grey-button ecp-delete ecp-delete-button" style="color:#646970; float: none; padding: 10px 15px;">
                                 <?php _e('delete', 'evergreen-content-poster'); ?>
                              </a>
                           </div>
                        </div>

                        <div class="ecp-clearfix"></div>

                        <p><?php _e('Or create new categories that suit your needs:', 'evergreen-content-poster'); ?></p>

                        <div class="ecp-grid ecp-col-300">
                           <a href="#add-category" rel="modal:open" class="button ecp-navy-button add-new-category-step" style="height: 50px; margin: 2px 0; float: none; padding: 17px 30px;"><?php _e('Add new category', 'evergreen-content-poster'); ?></a>
                        </div>

                        <div class="ecp-clearfix"></div>

                        <div class="ecp-grid-right">
                           <a href="#" class="button ecp-green-button ecp-next" data-step="2" style="color:#1b3a51; font-weight: 600;"><?php _e('next', 'evergreen-content-poster'); ?></a>
                        </div>
                        <div class="ecp-grid">
                           <a href="#" class="button ecp-grey-button ecp-previous" data-step="2" style="font-weight: 600;"><?php _e('previous', 'evergreen-content-poster'); ?></a>
                        </div>

                        <div id="edit-category" class="modal all-modal">
                           <h2 style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Edit your category', 'evergreen-content-poster'); ?></h2>
                           <p><strong><?php _e('Category name', 'evergreen-content-poster'); ?></strong></p>
                           <input style="width: 100%; margin: 0 0 1em 0;" type="text" class="category-name-input ecp-admin-input" name="category-name-input" value="">
                           <p><strong><?php _e('Description', 'evergreen-content-poster'); ?></strong></p>
                           <textarea style="width: 100%; height: 4rem;" class="category-description-input ecp-admin-input" name="category-description-input" value=""></textarea>
                           <div class="ecp-grid ecp-col-540">
                              <p><strong><?php _e('Can also be used as random category', 'evergreen-content-poster'); ?></strong></p>
                           </div>
                           <div class="ecp-grid ecp-col-300">
                              <input type="checkbox" class="field-setting ecp-hidden random_availability" name="random_availability" value="Y" data-ref="saved_random_availability" />
                              <input type="hidden" class="saved_random_availability" name="saved_random_availability" value="" />
                              <div class="ecp-checkbox-toggle-small" data-status="" data-field="random_availability">
                                 <div class="ecp-checkbox-on-small"><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                 <div class="ecp-checkbox-off-small"><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                              </div>
                           </div>

                           <div class="ecp-clearfix"></div>

                           <p><em><?php _e('If you chose "Random Category" (instead of a specific category) in your schedule for a particular account, we randomly select a category from those that have this checkbox turned on, and also have posts available for that particular account. Within the randomly selected category we use the next content in line.', 'evergreen-content-poster'); ?></em></p>
                           <div class="edit-category-action">
                              <div class="spinner"></div>
                              <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-edit-category-button"><?php _e('Save', 'evergreen-content-poster'); ?></a>
                              <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
                           </div>
                        </div>

                        <div id="delete-category" class="modal all-modal">
                           <h2 style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php echo sprintf(__('Delete category %s', 'evergreen-content-poster'), '<span class="modal-category-name"></span>') ?></h2>
                           <p><?php _e('Are you sure that you want to delete this content category?', 'evergreen-content-poster'); ?></p>

                           <div class="alert alert-warning">
                              <p><?php _e('Deleting a category will trigger the following changes:', 'evergreen-content-poster'); ?></p>
                              <ul>
                                 <li><?php _e('Any schedule related to this category will be removed.', 'evergreen-content-poster'); ?></li>
                              </ul>
                              <p><?php _e('Are you sure you want to remove this category?', 'evergreen-content-poster'); ?></p>
                           </div>

                           <div class="edit-category-action">
                              <div class="spinner"></div>
                              <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-delete-category-step"><?php _e('Delete', 'evergreen-content-poster'); ?></a>
                              <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
                           </div>
                        </div>

                        <div id="add-category" class="modal all-modal">
                           <h2 style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Create your category', 'evergreen-content-poster'); ?></h2>
                           <p><strong><?php _e('Category name', 'evergreen-content-poster'); ?></strong></p>
                           <input style="width: 100%; margin: 0 0 1em 0;" type="text" class="category-name-input ecp-admin-input" name="category-name-input" placeholder="<?php _e('Category name', 'evergreen-content-poster'); ?>">
                           <p><strong><?php _e('Description', 'evergreen-content-poster'); ?></strong></p>
                           <textarea style="width: 100%; height: 4rem;" class="category-description-input ecp-admin-input" name="category-description-input" placeholder="<?php _e('Give your category an internal description so you know what this should be about.', 'evergreen-content-poster'); ?>"></textarea>
                           <div class="ecp-grid ecp-col-540">
                              <p><strong><?php _e('Can also be used as random category', 'evergreen-content-poster'); ?></strong></p>
                           </div>
                           <div class="ecp-grid ecp-col-300">
                              <input type="checkbox" class="field-setting ecp-hidden" name="random_availability" value="Y" data-ref="saved_random_availability" />
                              <input type="hidden" name="saved_random_availability" value="on" />
                              <div class="ecp-checkbox-toggle-small" data-status="on" data-field="random_availability">
                                 <div class="ecp-checkbox-on-small"><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                 <div class="ecp-checkbox-off-small"><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                              </div>
                           </div>

                           <div class="ecp-clearfix"></div>

                           <p><em><?php _e('If you chose "Random Category" (instead of a specific category) in your schedule for a particular account, we randomly select a category from those that have this checkbox turned on, and also have posts available for that particular account. Within the randomly selected category we use the next content in line.', 'evergreen-content-poster'); ?></em></p>
                           <div class="edit-category-action">
                              <div class="spinner"></div>
                              <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-add-category-button jquery-modal-close"><?php _e('Create', 'evergreen-content-poster'); ?></a>
                              <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
                           </div>
                        </div>

                     </div> <!-- end step 2 -->

                     <!-- step 3 -->
                     <div id="step-3" class="step-content">
                        <h2 style="text-align: center;"><?php _e('Step 3:', 'evergreen-content-poster'); ?> <?php _e('Your content schedule', 'evergreen-content-poster'); ?></h2>
                        <p><?php _e('Within the Evergreen Content Poster, we allow for three different ways to schedule and share your content:', 'evergreen-content-poster'); ?></p>
                        <ol>
                           <li><?php _e('<strong>Share X number of posts every day to your social media profiles</strong>. This means that during the day your posts will be evenly scheduled for each social network (this is by far the easiest and quickest way to get started). If you put zero, this social channel will be skipped.', 'evergreen-content-poster'); ?></li>
                           <li><?php _e('Monitor the queues of your connected profiles on Buffer and <strong>only shares an item to your queue the moment it detects the queue is empty</strong>. (especially if you already schedule and share a lot of content via social media)', 'evergreen-content-poster'); ?></li>
                           <li><?php _e('<strong>On which day and at which time do you want your content to be shared to which social media account</strong>. (if you know your audience, and when they will be online, this would be our recommendation as it is the most customisable option)', 'evergreen-content-poster'); ?></li>
                        </ol>

                        <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-option-container .ecp-schedule-settings-title-wrapper">
                           <h2><?php _e('Schedule Settings', 'evergreen-content-poster'); ?></h2>
                        </div>

                        <div>
                           <form id="ecp_settings_config_form" method="post">
                              <div class="ecp-hidden">
                                 <input type="hidden" name="saved_posting_schedule" value="<?php echo $settings['ecp_posting_schedule']; ?>" />
                                 <?php
                                 $schedules_radios = [
                                    'timestamp' => 'timestamp',
                                    'daily' => 'daily_posts',
                                    'queue' => 'empty_queue',
                                 ];
                                 foreach ($schedules_radios as $key => $value) {
                                    $checked = '';
                                    if ($settings['ecp_posting_schedule'] === $value)
                                       $checked = 'checked';
                                 ?>
                                    <input type="radio" class="posting-schedule-<?php echo $key; ?>" name="ecp_posting_schedule" value="<?php echo $value; ?>" <?php echo $checked; ?> />
                                 <?php } // end foreach ($schedules_radios as $key => $value)
                                 ?>

                                 <input type="radio" class="posting-schedule-daily" name="ecp_posting_schedule" value="daily_posts" />
                                 <input type="radio" class="posting-schedule-queue" name="ecp_posting_schedule" value="empty_queue" />
                              </div>

                              <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting" style="position: relative">
                                 <div style="position: absolute; right: 0; top: 66px">
                                    <button id="save_settings_config" style="float: unset" class="button ecp-navy-button" disabled><?php _e('Save Changes', 'evergreen-content-poster'); ?></button>
                                    <div style="text-align: center" class="ecp-show-result hidden"></div>
                                 </div>
                                 <div class="tabs ecp-onboard">
                                    <input type="radio" name="tabs" class="" id="tabone" checked="checked" />
                                    <label class="ecp-tab-label" for="tabone"><?php _e('Post number of posts daily', 'evergreen-content-poster'); ?></label>
                                    <div class="tab">

                                       <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                          <div class="ecp-grid ecp-col-300 ecp-no-bottom-margin">
                                             <p class="ecp-input-label"><?php _e('#1 Post number of posts daily', 'evergreen-content-poster'); ?></p>
                                             <p class="description"><?php _e('Share X number of posts to your social media profiles evenly spread out during the day.', 'evergreen-content-poster'); ?></p>
                                          </div>

                                          <?php
                                          $isScheduleActive = ('daily_posts' === $settings['ecp_posting_schedule']) ? true : false;
                                          $buttonClass = '';
                                          $spanClass = 'ecp-hidden';
                                          if ($isScheduleActive) {
                                             $buttonClass = 'ecp-hidden';
                                             $spanClass = '';
                                          }
                                          ?>
                                          <div class="ecp-grid ecp-col-300">
                                             <button class="button ecp-navy-button ecp-activate-button active-post-daily <?php echo $buttonClass; ?> " data-radio="posting-schedule-daily"><?php _e('Activate', 'evergreen-content-poster'); ?></button>
                                             <span class="active active-scheduler <?php echo $spanClass; ?> "><?php _e('Currently Active', 'evergreen-content-poster'); ?></span>
                                          </div>
                                       </div>

                                       <?php foreach ($profiles as $service => $profile) { ?>
                                          <?php foreach ($profile as $value) { ?>
                                             <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                <div class="ecp-grid ecp-col-300">
                                                   <div class="ecp-connected-profile-avatar">
                                                      <img class="ecp-profile-circle" ng-src="<?php echo $value->avatar ?? (EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'); ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $value->avatar ?? (EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'); ?>" />
                                                      <div class="ecp-social-network-icon ecp-<?php echo strtolower($value->service); ?>"></div>
                                                   </div>
                                                   <p class="ecp-input-label">&nbsp;<?php _e('Posts per day', 'evergreen-content-poster'); ?></p>
                                                </div>
                                                <div class="ecp-grid ecp-col-300"><input data-radio="posting-schedule-daily" type="number" min="0" max="1440" required="true" name="post_per_day_<?php echo $value->id ?>" value="<?php echo isset($this->buffer_settings['post_per_day_' . $value->id]) ? $this->buffer_settings['post_per_day_' . $value->id] : '0' ?>" id="post_per_day_<?php echo $value->id ?>" class="ecp-admin-input post_per_day_change" data-ref="saved_post_per_day" aria-invalid="false" /></div>
                                             </div>
                                          <?php } // end foreach ($profile as $value)
                                          ?>
                                       <?php } // end foreach ($profiles as $service => $profile)
                                       ?>
                                    </div>

                                    <input type="radio" name="tabs" class="" id="tabtwo" />
                                    <label class="ecp-tab-label" for="tabtwo"><?php _e('Post only when Buffer queue gets empty', 'evergreen-content-poster'); ?></label>
                                    <div class="tab">
                                       <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                          <div class="ecp-grid ecp-col-300">
                                             <p class="ecp-input-label"><?php _e('#2 Post only when Buffer queue gets empty', 'evergreen-content-poster'); ?></p>
                                             <p class="description"><?php _e('Get posts to your Buffer queue every time it is empty', 'evergreen-content-poster'); ?></p>
                                          </div>

                                          <?php
                                          $isScheduleActive = ('empty_queue' === $settings['ecp_posting_schedule']) ? true : false;
                                          $buttonClass = '';
                                          $spanClass = 'ecp-hidden';
                                          if ($isScheduleActive) {
                                             $buttonClass = 'ecp-hidden';
                                             $spanClass = '';
                                          }
                                          ?>
                                          <div class="ecp-grid ecp-col-300">
                                             <button class="button ecp-navy-button ecp-activate-button <?php echo $buttonClass; ?> " data-radio="posting-schedule-queue"><?php _e('Activate', 'evergreen-content-poster'); ?></button>
                                             <span class="active active-scheduler <?php echo $spanClass; ?> "><?php _e('Currently Active', 'evergreen-content-poster'); ?></span>
                                          </div>
                                       </div>

                                       <?php foreach ($profiles as $service => $profile) { ?>
                                          <?php foreach ($profile as $value) {
                                             $profile_username = !empty($value->formatted_username) ? $value->formatted_username : ucwords($value->service_type) . ($key + 1);
                                             if (strlen($profile_username) > 18) {
                                                $profile_username = substr($profile_username, 0, 15) . '...';
                                             }

                                             $service_type = $value->service . ' ' . ucwords($value->service_type);
                                             if (strlen($service_type) > 17) {
                                                $service_type = substr($service_type, 0, 14) . '...';
                                             }
                                          ?>
                                             <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                                <div class="ecp-grid ecp-col-300">
                                                   <div class="ecp-connected-profile-avatar">
                                                      <img class="ecp-profile-circle" ng-src="<?php echo $value->avatar ?? (EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'); ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $value->avatar ?? (EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'); ?>">
                                                      <div class="ecp-social-network-icon ecp-<?php echo strtolower($value->service); ?>"></div>
                                                   </div>
                                                   <div class="ecp-connected-profile-name">
                                                      <span class="ecp-connected-profile-username">
                                                         <?php _e($profile_username, 'evergreen-content-poster'); ?>
                                                      </span>
                                                      <br />
                                                      <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                   </div>
                                                </div>
                                                <div class="ecp-grid ecp-col-300">
                                                   <?php
                                                   $checked = (isset($settings['empty_queue_status_' . $value->id]) && $settings['empty_queue_status_' . $value->id] === 'Y') ? 'checked' : '';
                                                   $data_status = (isset($settings['empty_queue_status_' . $value->id]) && $settings['empty_queue_status_' . $value->id] === 'Y') ? 'on' : 'off';
                                                   ?>
                                                   <input type="checkbox" class="field-setting ecp-hidden" name="empty_queue_status_<?php echo $value->id ?>" value="Y" <?php echo $checked; ?> data-ref="saved_empty_queue_status_<?php echo $value->id ?>" />
                                                   <input type="hidden" name="saved_empty_queue_status_<?php echo $value->id ?>" value="<?php echo isset($settings['empty_queue_status_' . $value->id]) ? $settings['empty_queue_status_' . $value->id] : 'N'; ?>" />
                                                   <div class="ecp-checkbox-toggle" data-status="<?php echo $data_status; ?>" data-field="empty_queue_status_<?php echo $value->id ?>">
                                                      <div class="ecp-checkbox-on"><?php _e('ON', 'evergreen-content-poster'); ?></div>
                                                      <div class="ecp-checkbox-off"><?php _e('OFF', 'evergreen-content-poster'); ?></div>
                                                   </div>
                                                </div>
                                             </div>
                                          <?php } // end foreach ($profile as $value)
                                          ?>
                                       <?php } //end foreach ($profiles as $service => $profile)
                                       ?>
                                    </div>

                                    <input type="radio" name="tabs" class="" id="tabthree" />
                                    <label class="ecp-tab-label" for="tabthree"><?php _e('Post according to schedule', 'evergreen-content-poster'); ?></label>
                                    <div class="tab">
                                       <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                          <div class="ecp-grid ecp-col-300">
                                             <p class="ecp-input-label"><?php _e('#3 Schedule', 'evergreen-content-poster'); ?></p>
                                             <p class="description"><?php _e('Send posts at specific times using a custom schedule', 'evergreen-content-poster'); ?></p>
                                             <p class="description"><?php _e('Not sure when it is best to share your content, or are you looking for a quick way to create one? Use one of the preset schedules to post according to general best practices for each platform.', 'evergreen-content-poster'); ?></p>
                                          </div>

                                          <?php
                                          $isScheduleActive = ('timestamp' === $settings['ecp_posting_schedule']) ? true : false;
                                          $buttonClass = '';
                                          $spanClass = 'ecp-hidden';
                                          if ($isScheduleActive) {
                                             $buttonClass = 'ecp-hidden';
                                             $spanClass = '';
                                          }
                                          ?>
                                          <div class="ecp-grid ecp-col-300">
                                             <button class="button ecp-navy-button ecp-activate-button <?php echo $buttonClass; ?> " data-radio="posting-schedule-timestamp"><?php _e('Activate', 'evergreen-content-poster'); ?></button>
                                             <span class="active active-scheduler <?php echo $spanClass; ?> "><?php _e('Currently Active', 'evergreen-content-poster'); ?></span>
                                          </div>
                                       </div>

                                       <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                          <p><strong><?php _e('How often do you want to post?', 'evergreen-content-poster'); ?></strong></p>

                                          <form id="ecp-frequency-form" action="">
                                             <input type="hidden" id="isset_custom_frequency" value="<?php echo isset($ecp_frequency_schedules['custom']) && !empty($ecp_frequency_schedules['custom']) ? 1 : 0 ?>">
                                             <input type="hidden" id="use-pre-schedule" value="0">
                                             <div class="radio ecp-checkbox-primary">
                                                <input <?php $arr = (array) $selected_profile;
                                                         if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?> id="ecp-post-freq-seldom" type="radio" value="seldom" class="" name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] === 'seldom') { ?> checked<?php } ?>>
                                                <label for="ecp-post-freq-seldom"><?php _e('Now and again', 'evergreen-content-poster'); ?></label>
                                             </div>
                                             <div class="radio ecp-checkbox-primary">
                                                <input <?php $arr = (array) $selected_profile;
                                                         if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?> id="ecp-post-freq-regularly" type="radio" value="regularly" class="" name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] === 'regularly') { ?> checked<?php } ?>>
                                                <label for="ecp-post-freq-regularly"><?php _e('Regularly', 'evergreen-content-poster'); ?></label>
                                             </div>
                                             <div class="radio ecp-checkbox-primary">
                                                <input <?php $arr = (array) $selected_profile;
                                                         if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?> id="ecp-post-freq-often" type="radio" value="often" class="" name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] === 'often') { ?> checked<?php } ?>>
                                                <label for="ecp-post-freq-often"><?php _e('Often', 'evergreen-content-poster'); ?></label>
                                             </div>
                                             <div class="radio ecp-checkbox-primary">
                                                <?php if (!(isset($ecp_frequency_schedules['custom']) && !empty($ecp_frequency_schedules['custom']))) { ?>
                                                   <a href="#confirm-custom-schedule-modal" rel="modal:open" class="show-popup-confirm-custom">
                                                      <input <?php $arr = (array) $selected_profile;
                                                               if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?> id="ecp-post-freq-custom" type="radio" value="custom" class="" name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] === 'custom') { ?> checked<?php } ?>>
                                                      <label for="ecp-post-freq-custom"><?php _e('Custom', 'evergreen-content-poster'); ?></label>
                                                      <span ng-show="selectedProfiles.postFrequency === 'custom'" uib-popover-html="'<span><?php _e('You\'re now using a custom schedule. You can also replace it with one of our presets from above, based on best practices.', 'evergreen-content-poster'); ?></span><br/> <br/><span><?php _e('Keep in mind that the preset will take the place of your current schedule if you do.', 'evergreen-content-poster'); ?></span>'" popover-trigger="mouseenter" popover-append-to-body="true" class="ng-hide">
                                                         <i class="fa fa-info-circle" aria-hidden="true"></i>
                                                      </span>
                                                   </a>
                                                <?php } else { ?>
                                                   <input <?php $arr = (array) $selected_profile;
                                                            if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?> id="ecp-post-freq-custom" type="radio" value="custom" class="" name="ecp-frequency" <?php if (isset($options['ecp_frequency']) && $options['ecp_frequency'] === 'custom') { ?> checked<?php } ?>>
                                                   <label for="ecp-post-freq-custom"><?php _e('Custom', 'evergreen-content-poster'); ?></label>
                                                   <span ng-show="selectedProfiles.postFrequency === 'custom'" uib-popover-html="'<span><?php _e('You\'re now using a custom schedule. You can also replace it with one of our presets from above, based on best practices.', 'evergreen-content-poster'); ?></span><br/> <br/><span><?php _e('Keep in mind that the preset will take the place of your current schedule if you do.', 'evergreen-content-poster'); ?></span>'" popover-trigger="mouseenter" popover-append-to-body="true" class="ng-hide">
                                                      <i class="fa fa-info-circle" aria-hidden="true"></i>
                                                   </span>
                                                <?php } ?>
                                             </div>
                                          </form>
                                       </div>

                                       <div class="<?php if (!isset($options['ecp_frequency']) || $options['ecp_frequency'] !== 'custom') { ?> hidden <?php } ?> ecp-grid ecp-col-940 ecp-option-container ecp-field-setting add-schedule-block" <?php if (!empty($schedule->times)) {
                                                                                                                                                                                                                                                   echo "style:'margin-bottom:0;'";
                                                                                                                                                                                                                                                } ?>>
                                          <input type="hidden" name="ecp_schedule_days" id="ecp_schedule_days" class="ecp_schedule_days" value="every_day">
                                          <div class="ecp-grid ecp-col-160">
                                             <div class="ecp-grid-right ecp-day-dropdown">
                                                <a href="javascript:void(0)" class="ecp-col-940 button ecp-show-days">
                                                   <?php _e('Every Day', 'evergreen-content-poster'); ?>
                                                   <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2 ecp-arrow-down"></span></a>
                                                <ul class="ecp-day-list">
                                                   <?php
                                                   $days_define = [
                                                      'every_day' => 'Every Day',
                                                      'weekdays' => 'Weekdays',
                                                      'weekends' => 'Weekends',
                                                      '0' => 'Monday',
                                                      '1' => 'Tuesday',
                                                      '2' => 'Wednesday',
                                                      '3' => 'Thursday',
                                                      '4' => 'Friday',
                                                      '5' => 'Saturday',
                                                      '6' => 'Sunday',
                                                   ];
                                                   foreach ($days_define as $key => $value) {
                                                   ?>
                                                      <li>
                                                         <div class="ecp-grid ecp-col-940">
                                                            <a href="javascript:void(0)" data-name="<?php _e($value, 'evergreen-content-poster'); ?>" data-day="<?php echo $key ?>" class="button ecp-day-single-setting">
                                                               <div class="ecp-connected-profilex">
                                                                  <div class="ecp-connected-profile-avatar">
                                                                     <span class="ecp-connected-profile-day"><?php _e($value, 'evergreen-content-poster'); ?></span>
                                                                  </div>
                                                               </div>
                                                            </a>
                                                         </div>
                                                      </li>
                                                   <?php } // end foreach ($days_define as $key => $value)
                                                   ?>
                                                </ul>
                                             </div>
                                          </div>

                                          <div class="ecp-grid ecp-col-60">
                                             <select name="ecp_schedule_hours" id="ecp_schedule_hours" class="ecp_schedule_hours" aria-invalid="false">
                                                <?php foreach (range(0, 23) as $hour) { ?>
                                                   <?php
                                                   if ($hour < 10) {
                                                      $hour = str_pad($hour, 2, '0', STR_PAD_LEFT);
                                                   }

                                                   $selected = '';
                                                   if (empty($schedules['hour']) && 12 === $hour) {
                                                      $selected = 'selected';
                                                   } ?>
                                                   <option value="<?php echo $hour; ?>" <?php echo $selected; ?> aria-checked="true"><?php _e((string) $hour, 'evergreen-content-poster'); ?></option>
                                                <?php } // end foreach (range(0, 23) as $hour)
                                                ?>
                                             </select>
                                          </div>

                                          <div class="ecp-grid ecp-col-60">
                                             <select name="ecp_schedule_minutes" id="ecp_schedule_minutes" class="ecp_schedule_minutes" aria-invalid="false">
                                                <?php foreach (range(0, 59) as $minute) { ?>
                                                   <?php
                                                   if ($minute < 10) {
                                                      $minute = str_pad($minute, 2, '0', STR_PAD_LEFT);
                                                   }

                                                   $selected = '';
                                                   if (isset($settings['ecp_schedule_minutes']) && $minute === $settings['ecp_schedule_minutes']) {
                                                      $selected = 'selected';
                                                   } ?>
                                                   <option value="<?php echo $minute; ?>" <?php echo $selected; ?> aria-checked="true"><?php _e((string) $minute, 'evergreen-content-poster'); ?></option>
                                                <?php } // end foreach (range(0, 59) as $minute)
                                                ?>
                                             </select>
                                          </div>

                                          <div class="ecp-grid ecp-col-160">
                                             <div class="ecp-grid-right ecp-network-dropdown">
                                                <a href="javascript:void(0)" class="ecp-col-940 button ecp-show-networks"><?php _e('Select Social Network', 'evergreen-content-poster'); ?> <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2"></span></a>
                                                <ul class="ecp-network-list">
                                                   <li>
                                                      <div class="ecp-grid ecp-col-940">
                                                         <a href="javascript:void(0)" data-username="<?php _e('All networks', 'evergreen-content-poster'); ?>" data-profile="<?php echo 'all_networks' ?>" class="button ecp-network-single-setting">
                                                            <div class="ecp-connected-profilex">
                                                               <div class="ecp-connected-profile-avatar">
                                                                  <span class="ecp-connected-profile-network"><?php _e('All networks', 'evergreen-content-poster'); ?></span>
                                                               </div>
                                                            </div>
                                                         </a>
                                                      </div>
                                                   </li>
                                                   <?php foreach ($this->buffer->profiles() as $service => $profile_list) { ?>
                                                      <?php
                                                      foreach ($profile_list as $key => $single_profile) {
                                                         $avatar = EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png';
                                                         if (!empty($single_profile->avatar)) {
                                                            $avatar = $single_profile->avatar;
                                                         }

                                                         $profile_username = !empty($single_profile->formatted_username) ? $single_profile->formatted_username : ucwords($single_profile->service_type) . ($key + 1);
                                                         if (strlen($profile_username) > 18) {
                                                            $profile_username = substr($profile_username, 0, 15) . '...';
                                                         }

                                                         $service_type = ucwords($single_profile->service . ' ' . ucwords($single_profile->service_type));
                                                         if (strlen($service_type) > 17) {
                                                            $service_type = substr($service_type, 0, 14) . '...';
                                                         } ?>
                                                         <li>
                                                            <div class="ecp-grid ecp-col-940">
                                                               <a href="javascript:void(0)" data-username="<?php echo $single_profile->formatted_username; ?>" data-profile="<?php echo $single_profile->id; ?>" data-service="<?php echo ucwords($single_profile->service) . '-' . ucwords($single_profile->service_type); ?>" data-avatar="<?php echo $avatar ?>" data-social="<?php echo ucwords($single_profile->service) ?>" class="button ecp-network-single-setting">
                                                                  <div class="ecp-connected-profilex">
                                                                     <div class="ecp-connected-profile-avatar">
                                                                        <img class="ecp-profile-circle-medium" ng-src="<?php echo $avatar; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $avatar; ?>">
                                                                        <div class="ecp-social-network-icon-medium ecp-<?php echo strtolower($single_profile->service); ?>"></div>
                                                                        <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                                     </div>
                                                                  </div>
                                                               </a>
                                                            </div>
                                                         </li>
                                                   <?php
                                                      } // end foreach ($profile_list as $key => $single_profile)
                                                   } // end foreach ($this->buffer->profiles() as $service => $profile_list)
                                                   ?>
                                                </ul>
                                             </div>
                                          </div>

                                          <div class="ecp-grid ecp-col-160">
                                             <input type="hidden" name="ecp_schedule_categories" id="ecp_schedule_categories" class="ecp_schedule_cateories" value="">
                                             <div class="ecp-grid-right ecp-categories-dropdown">
                                                <a href="javascript:void(0)" class="ecp-col-940 button ecp-show-category"><?php _e('Select Category', 'evergreen-content-poster'); ?>
                                                   <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2 ecp-arrow-down"></span>
                                                </a>
                                                <ul class="ecp-categories-list">
                                                   <?php
                                                   foreach ($allCategories as $category) {
                                                      if (strlen($category->name) > 17) {
                                                         $category->name = substr($category->name, 0, 14) . '...';
                                                      } ?>
                                                      <li>
                                                         <div class="ecp-grid ecp-col-940">
                                                            <a href="javascript:void(0)" data-id="<?php echo $category->id ?>" data-name="<?php echo $category->name ?>" class="button ecp-categories-single-setting">
                                                               <div class="ecp-connected-profilex">
                                                                  <div class="ecp-connected-profile-avatar">
                                                                     <span class="ecp-connected-profile-categories"><?php echo $category->name ?></span>
                                                                  </div>
                                                               </div>
                                                            </a>
                                                         </div>
                                                      </li>
                                                   <?php
                                                   } // end foreach ($allCategories as $category)
                                                   ?>
                                                   <li>
                                                      <div class="ecp-grid ecp-col-940">
                                                         <a href="javascript:void(0)" data-id="0" data-name="<?php _e('Random category', 'evergreen-content-poster'); ?>" class="button ecp-categories-single-setting">
                                                            <div class="ecp-connected-profilex">
                                                               <div class="ecp-connected-profile-avatar">
                                                                  <span class="ecp-connected-profile-categories"><?php _e('Random category', 'evergreen-content-poster'); ?></span>
                                                               </div>
                                                            </div>
                                                         </a>
                                                      </div>
                                                   </li>
                                                </ul>
                                             </div>
                                          </div>

                                          <input type="hidden" id="ecp_schedule_network" value="" name="ecp_schedule_network" class="ecp_schedule_network">

                                          <div class="ecp-add-schedule-custom">
                                             <div class="ecp-grid ecp-col-220">
                                                <button class="button ecp-navy-button ecp-save-settings ecp-add-schedule" <?php $arr = (array) $selected_profile;
                                                                                                                           if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?> style="margin: 4px 0;"><?php _e('Add Posting Time', 'evergreen-content-poster'); ?></button>
                                             </div>
                                          </div>
                                       </div>

                                       <script>
                                          jQuery(function($) {
                                             $(document).on('click', '.ecp-activate-button', function(e) {
                                                e.preventDefault();
                                                $(this).removeClass('ecp-navy-button');
                                                $(this).addClass('ecp-red-button');
                                                $(this).css({
                                                   "float": 'left',
                                                   "text-transform": "lowercase",
                                                   "margin-left": "10%"
                                                });
                                                let radioTarget = $(this).data('radio');
                                                $('.' + radioTarget).trigger('click');

                                                let savedValField = document.querySelector('input[name="saved_posting_schedule"]');
                                                let newValField = document.querySelector('input[name="ecp_posting_schedule"]:checked');

                                                toggleSaveSetting(false);
                                                $('input[name="saved_posting_schedule"]').val(newValField.value)
                                                toggleSaveSetting(true);

                                                return false;
                                             });

                                             $('.ecp-add-schedule').on('click', function(e) {
                                                e.preventDefault();

                                                let network = document.querySelector('.ecp_schedule_network');
                                                let network_new = document.querySelector('.ecp-show-networks');

                                                network_new.classList.remove('ecp-input-error');
                                                if (network.value == '0') {
                                                   network.classList.add('ecp-input-error');

                                                   return;
                                                }

                                             });

                                             $('a.ecp-profile-select').on('click', function(evt) {
                                                // evt.preventDefault();

                                                const profileBtn = this;

                                                const connectedProfiles = document.querySelectorAll('.ecp-connected-profile');
                                                for (var i = 0; i <= connectedProfiles.length - 1; i++) {
                                                   connectedProfiles[i].classList.remove = 'active';
                                                }
                                                profileBtn.querySelector('.ecp-connected-profile').classList.add = 'active';

                                             });

                                             // trigger and show correct tab
                                             var activeSchedule = '<?php echo $settings['ecp_posting_schedule']; ?>';

                                             if ('timestamp' == activeSchedule)
                                                document.querySelector('#tabthree').click();
                                             if ('daily_posts' == activeSchedule)
                                                document.querySelector('#tabone').click();
                                             if ('empty_queue' == activeSchedule)
                                                document.querySelector('#tabtwo').click();
                                          });
                                       </script>

                                       <?php
                                       $is_empty_schedule_clear = true;
                                       $arrProfile = (array) $selected_profile;
                                       if (empty($arrProfile)) {
                                          foreach ($scheduleDefineLast as $schedule) {
                                             if (!empty($schedule->times)) {
                                                $is_empty_schedule_clear = false;
                                             }
                                          } // end foreach ($scheduleDefineLast as $schedule)
                                       } else {
                                          foreach ($selected_schedules as $schedule) {
                                             if (!empty($schedule->times)) {
                                                $is_empty_schedule_clear = false;
                                             }
                                          } // end foreach ($selected_schedules as $schedule)
                                       }

                                       $categoriesInactive = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}evergreen_categories WHERE status != 1");
                                       ?>
                                       <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting clear-schedule-box <?php if ($is_empty_schedule_clear) { ?> hidden <?php } ?>">
                                          <div class="ecp-grid ecp-col-300">
                                             <a href="#clear-schedule" class="ecp-clear-schedule-class" rel="modal:open"><?php _e('Clear Schedule', 'evergreen-content-poster'); ?></a>
                                             <?php if (!empty((array) $categoriesInactive)) { ?>
                                                <p><?php _e('At the moment the following categories are inactive and content of these categories will not be posted to your social media channels:', 'evergreen-content-poster'); ?></p>
                                                <ul>
                                                   <?php foreach ($categoriesInactive as $categoryIn) { ?>
                                                      <li><strong><?php echo $categoryIn->name ?></strong></li>
                                                   <?php } //end foreach ($categoriesInactive as $categoryIn)
                                                   ?>
                                                </ul>
                                             <?php } ?>

                                             <div id="clear-schedule" class="modal all-modal">
                                                <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Are you sure you want to clear your entire posting schedule?', 'evergreen-content-poster') ?></p>
                                                <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-clear-schedule jquery-modal-close" <?php $arr = (array) $selected_profile;
                                                                                                                                                               if (!empty($arr)) { ?> data-id="<?php echo $selected_profile->id ?>" data-service="<?php echo $selected_profile->service ?>" <?php } ?>><?php _e('Ok', 'evergreen-content-poster') ?></a>
                                                <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
                                             </div>
                                          </div>
                                       </div>

                                       <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                          <ul class="ecp-schedule">
                                             <?php
                                             $daysWeek = [
                                                '0' => 'Sunday',
                                                '1' => 'Monday',
                                                '2' => 'Tuesday',
                                                '3' => 'Wednesday',
                                                '4' => 'Thursday',
                                                '5' => 'Friday',
                                                '6' => 'Saturday',
                                             ];
                                             foreach ($daysWeek as $key => $value) { ?>
                                                <li>
                                                   <div class="ecp-schedule_day">
                                                      <div class="ecp-schedule-day-header">
                                                         <?php _e($value, 'evergreen-content-poster'); ?>
                                                      </div>
                                                   </div>
                                                </li>
                                             <?php } // end foreach ($daysWeek as $key => $value)
                                             ?>
                                          </ul>

                                          <div id="ecp-schedule-body">
                                             <?php if (!empty((array) $selected_profile)) { ?>
                                                <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                                                   <?php
                                                   $is_empty_schedule = true;
                                                   if (isset($_REQUEST['ecp_profile'])) {
                                                      foreach ($selected_schedules as $schedule) {
                                                         if (!empty($schedule->times)) {
                                                            $is_empty_schedule = false;
                                                         }
                                                      }
                                                   }
                                                   ?>
                                                   <?php if (!$is_empty_schedule) { ?>
                                                      <?php foreach ($selected_schedules as $ds_key => $daily_schedule) { ?>
                                                         <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                                                            <?php
                                                            $times = [];
                                                            foreach ($daily_schedule->times as $time) {
                                                               if (strlen($time['time_push']) === 4) {
                                                                  $time['time_push'] = '0' . $time['time_push'];
                                                               }
                                                               $times[] = $time;
                                                            } // end foreach ($daily_schedule->times as $time)
                                                            $daily_schedule->times = $times;
                                                            sort($daily_schedule->times);
                                                            foreach ($daily_schedule->times as $key => $value) { ?>
                                                               <a href="#delete-schedule" class="show-modal-delete" rel="modal:open" data-day="<?php echo $daily_schedule->days[0] ?>" data-id="<?php echo $selected_profile->_id ?>" data-service="<?php echo $selected_profile->service ?>" data-value="<?php echo $value['time_push'] ?>" data-key="<?php echo $key ?>" data-general="0">
                                                                  <div class="ecp-grid ecp-col-940 scheduled-item">
                                                                     <div class="ecp-connected-profile-avatar">
                                                                        <img class="ecp-profile-circle" ng-src="<?php echo $selected_profile->avatar; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $selected_profile->avatar; ?>" />
                                                                        <div class="ecp-social-network-icon ecp-<?php echo strtolower($selected_profile->service); ?>"></div>
                                                                     </div>
                                                                     <div class="ecp-text">
                                                                        <span class="schedule_field schedule_time"><?php _e($value['time_push'], 'evergreen-content-poster'); ?></span><br />
                                                                        <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen-content-poster') ?></span>
                                                                        <input type="hidden" name="scheduled_daytime[<?php echo $selected_profile->id; ?>][<?php echo $ds_key; ?>][]" value="<?php echo $value['time_push']; ?>" />
                                                                        <p class="ecp-remove-schedule hidden"><span class="dashicons dashicons-no"></span></p>
                                                                     </div>

                                                                     <?php if (!in_array($value['category_id'], $categoryIds)) { ?>
                                                                        <div class="ecp-overlay"><span class="dashicons dashicons-controls-pause"></span></div>
                                                                     <?php } ?>
                                                                  </div>
                                                               </a>
                                                            <?php } // end foreach ($daily_schedule->times as $key => $value)
                                                            ?>
                                                         </div>
                                                      <?php
                                                      } // end foreach ($selected_schedules as $ds_key => $daily_schedule)
                                                      ?>

                                                   <?php } else { ?>
                                                      <div class="ecp-grid ecp-col-940">
                                                         <span class="">
                                                            <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg" width="180" height="124" style="display: block; margin: 3em auto;">
                                                            <p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
                                                         </span>
                                                      </div>
                                                   <?php } ?>
                                                </div>
                                             <?php } else { ?>
                                                <div class="ecp-col-940 ecp-option-container ecp-field-setting no_schedule">
                                                   <?php
                                                   $is_empty_schedule = true;

                                                   foreach ($scheduleDefineLast as $schedule) {
                                                      if (!empty($schedule->times)) {
                                                         $is_empty_schedule = false;
                                                      }
                                                   } // end foreach ($scheduleDefineLast as $schedule)
                                                   ?>
                                                   <?php if (!$is_empty_schedule) { ?>
                                                      <?php foreach ($scheduleDefineLast as $ds_key => $daily_schedule) { ?>
                                                         <div class="ecp-grid ecp-col-130" style="margin-right: 0.9%">
                                                            <?php foreach ($daily_schedule->times as $key => $value) { ?>
                                                               <a href="#delete-schedule" class="show-modal-delete" rel="modal:open" data-day="<?php echo $daily_schedule->days[0] ?>" data-id="<?php echo $value['_id'] ?>" data-service="<?php echo $value['service'] ?>" data-value="<?php echo $value['time'] ?>" data-key="<?php echo $value['key'] ?>" data-general="1">
                                                                  <div class="ecp-grid ecp-col-940 scheduled-item">
                                                                     <div class="ecp-connected-profile-avatar">
                                                                        <img class="ecp-profile-circle" ng-src="<?php echo $value['avatar']; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $value['avatar']; ?>">
                                                                        <div class="ecp-social-network-icon ecp-<?php echo strtolower($value['service']); ?>"></div>
                                                                     </div>
                                                                     <div class="ecp-text">
                                                                        <span class="schedule_field schedule_time"><?php _e($value['time'], 'evergreen-content-poster'); ?></span><br />
                                                                        <span class="schedule_field schedule_category"><?php echo $value['category_id'] ? $allCategoriesName[$value['category_id']] : _e('Random category', 'evergreen-content-poster') ?></span>
                                                                        <input type="hidden" name="scheduled_daytime[<?php echo $value['_id']; ?>][<?php echo $ds_key; ?>][]" value="<?php echo $value['time']; ?>" />
                                                                        <p class="ecp-remove-schedule hidden"><span class="dashicons dashicons-no"></span></p>
                                                                     </div>

                                                                     <?php if (!in_array($value['category_id'], $categoryIds)) { ?>
                                                                        <div class="ecp-overlay"><span class="dashicons dashicons-controls-pause"></span></div>
                                                                     <?php } ?>
                                                                  </div>
                                                               </a>
                                                            <?php } // end foreach ($daily_schedule->times as $key => $value)
                                                            ?>
                                                         </div>
                                                      <?php } // end foreach ($scheduleDefineLast as $ds_key => $daily_schedule)
                                                      ?>

                                                   <?php } else { ?>
                                                      <div class="ecp-grid ecp-col-940">
                                                         <span class="">
                                                            <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-schedule.svg" width="180" height="124" style="display: block; margin: 3em auto;">
                                                            <p style="text-align: center;"><?php _e('There is no schedule at the moment, please use the form above to create your schedule.', 'evergreen-content-poster'); ?></p>
                                                         </span>
                                                      </div>
                                                   <?php } ?>
                                                </div>
                                             <?php }
                                             if (count($allCategories) > 1 && $totalNum > 0) {
                                                include plugin_dir_path(dirname(__FILE__)) . 'admin/partials/evergreen_content_statistics.php';
                                             }
                                             ?>
                                          </div>

                                       </div>

                                    </div><!-- end tab -->
                                 </div>
                                 <?php wp_nonce_field('evergreen-settings-config-save', 'evergreen-settings-config-save'); ?>
                              </div>
                           </form>
                        </div>

                        <div class="ecp-grid-right">
                           <a href="#" class="button ecp-green-button ecp-next" data-step="3" style="color:#1b3a51; font-weight: 600;"><?php _e('next', 'evergreen-content-poster'); ?></a>
                        </div>
                        <div class="ecp-grid">
                           <a href="#" class="button ecp-grey-button ecp-previous" data-step="3" style="font-weight: 600;"><?php _e('previous', 'evergreen-content-poster'); ?></a>
                        </div>

                     </div> <!-- end step 3 -->

                     <!-- step 4 -->
                     <div id="step-4" class="step-content">
                        <label class="hidden category"><?php _e('category', 'evergreen-content-poster'); ?></label>
                        <label class="hidden saving-post"><?php echo sprintf(
                                                               /* translators: %s is the name of a social network e.g. Facebook */
                                                               __('Adding content item to your %s queue', 'evergreen-content-poster'),
                                                               '<span class="saving-network-name"></span>'
                                                            ) ?></label>
                        <label class="hidden saving-default"><?php _e('Saving Category', 'evergreen-content-poster'); ?></label>

                        <label class="hidden saving-post-success"><?php echo sprintf(
                                                                     /* translators: %s is the name of a social network e.g. Facebook */
                                                                     __('Content item successfully added to your %s queue', 'evergreen-content-poster'),
                                                                     '<span class="saving-network-name"></span>'
                                                                  ) ?></label>
                        <label class="hidden saving-post-error"><?php echo sprintf(
                                                                     /* translators: %s is the name of a social network e.g. Facebook */
                                                                     __('There was a problem adding this content item to your %s queue', 'evergreen-content-poster'),
                                                                     '<span class="saving-network-name"></span>'
                                                                  ) ?></label>
                        <label class="hidden sharing-now"><?php echo sprintf(
                                                               /* translators: %s is the name of a social network e.g. Facebook */
                                                               __('Sharing to your %s', 'evergreen-content-poster'),
                                                               '<span class="social-network-name"></span>'
                                                            ) ?></label>
                        <label class="hidden shared-now"><?php echo sprintf(
                                                            /* translators: %s is the name of a social network e.g. Facebook */
                                                            __('Successfully shared to your %s', 'evergreen-content-poster'),
                                                            '<span class="social-network-name"></span>'
                                                         ) ?></label>
                        <label class="hidden adding-now"><?php echo sprintf(
                                                            /* translators: %s is the name of a social network e.g. Facebook */
                                                            __('Adding message to your %s', 'evergreen-content-poster'),
                                                            '<span class="social-network-name"></span>'
                                                         ) ?></label>
                        <label class="hidden added-now"><?php echo sprintf(
                                                            /* translators: %s is the name of a social network e.g. Facebook */
                                                            __('Successfully added message to your %s', 'evergreen-content-poster'),
                                                            '<span class="social-network-name"></span>'
                                                         ) ?></label>
                        <label class="hidden default-error"><?php _e('An error has occurred, please try again later', 'evergreen-content-poster') ?></label>

                        <label class="hidden ecp-custom-text"><?php _e('Do you want to use your current schedule as a basis to build your own schedule?', 'evergreen-content-poster'); ?></label>
                        <h2 style="text-align: center;"><?php _e('Step 4:', 'evergreen-content-poster'); ?> <?php _e('Create your first post', 'evergreen-content-poster'); ?></h2>

                        <p><?php _e('Almost there, this will be the final step to start posting your content, followed by two quick steps where we would like to get to know you a little bit better.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('In this step you will learn the two ways you can add a post into one of your content posting categories.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('The first one will be via the block underneath each post/page/custom post type in your WordPress backend. Adding content like this, ties the post directly to that piece of content in your WordPress installation, and the URL of that piece of content will be automatically added as a result.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('The second way to add content to your evergreen content library, is by adding posts from the library screen. By adding posts like this, you can add freeform posts that isn\'t directly linked to your WordPress website and you can insert a URL manually. This is great if you want to keep on sharing your YouTube video\'s for example, or if you want to share inspirational quotes or engaging questions with your audience.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('Let\'s start by adding posts to share your evergreen content from this WordPress installation.', 'evergreen-content-poster'); ?></p>
                        <p style="margin-bottom: 4rem;"><?php _e('This is a list of your five most recent WordPress posts, choose one and click on "add evergreen content".', 'evergreen-content-poster'); ?></p>

                        <?php
                        $recent_posts = wp_get_recent_posts([
                           'numberposts' => 5, // Number of recent posts thumbnails to display
                           'post_status' => 'publish', // Show only the published posts
                        ]);
                        foreach ($recent_posts as $post_item) {
                        ?>

                           <div class="ecp-grid ecp-col-60">
                              <img src="<?php if (has_post_thumbnail($post_item['ID'])) {
                                             echo get_the_post_thumbnail_url($post_item['ID']);
                                          } else {
                                             echo EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-image-not-found.png';
                                          } ?>" class="ecp-configurator-featured-image">
                           </div>
                           <div class="ecp-grid ecp-col-540">
                              <div class="ecp-configurator-post-meta">
                                 <a href="#add-evergreen-content-<?php echo $post_item['ID']; ?>" rel="modal:open">
                                    <h3><?php echo $post_item['post_title'] ?></h3>
                                    <p><?php echo sprintf(
                                          /* translators: %1s is the date and the name of the author */
                                          __('Published on %1s by %2s', 'evergreen-content-poster'),
                                          $post_item['post_date'],
                                          get_the_author_meta('nickname', $post_item['post_author'])
                                       )
                                       ?></p>
                                 </a>
                              </div>
                           </div>
                           <div class="ecp-grid ecp-col-160">
                              <a data-id="<?php echo $post_item['ID'] ?>" href="#add-evergreen-content-<?php echo $post_item['ID'] ?>" rel="modal:open" class="button ecp-navy-button ecp-show-modal-popup" style="font-weight: 600;"><?php _e('add evergreen content', 'evergreen-content-poster'); ?></a>
                           </div>
                           <div class="ecp-clearfix"></div>

                           <div id="add-evergreen-content-<?php echo $post_item['ID']; ?>" class="modal" style="max-width: 60%; left: 90px;">
                              <div class="ecp-grid ecp-col-940 ecp-fit ecp-loading-saving ecp-loading-saving-popup"><?php _e('Saving Settings', 'evergreen-content-poster'); ?></div>
                              <h2 style="text-align: center;"><?php _e('Your post:', 'evergreen-content-poster'); ?> <?php echo $post_item['post_title'] ?></h2>
                              <hr class="ecp-section ecp-grid ecp-col-940">

                              <?php echo apply_filters('the_content', sanitize_textarea_field(stripslashes_deep(get_post_field('post_content', $post_item['ID'])))); ?>
                              <hr class="ecp-section ecp-grid ecp-col-940">

                              <!-- start add evergreen content block -->
                              <div class="ecp-grid ecp-col-940">
                                 <div class="ecp-admin-tab ecp-grid ecp-col-940" style="display: block;">

                                    <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-option-container">
                                       <h2><?php _e('Double Your Traffic from Social Media with the Evergreen Content Poster', 'evergreen-content-poster'); ?></h2>
                                    </div>

                                    <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-posts-form-block">
                                       <div class="ecp-grid ecp-col-940">
                                          <p class="ecp-metabox-p"><?php _e('Many businesses are publishing content as a way to build their audiences and increase traffic to their websites. However, they may not be getting everything they could from each piece of content they create.', 'evergreen-content-poster'); ?></p>
                                          <p class="ecp-metabox-p"><?php _e('If you are serious about your content, then you also need to be serious about driving as much traffic to it (over social media) as possible. One great way to do this is to <em>share your content on social media more than once.</em>', 'evergreen-content-poster'); ?></p>
                                          <p class="ecp-metabox-p"><?php _e('Below you can add as many variations of your content to be shared to all different (social) media channels as you want. Items to think about are:', 'evergreen-content-poster'); ?></p>

                                          <ul class="ecp-metabox-ul">
                                             <li><?php _e('Post an interesting question that is answered by the post.', 'evergreen-content-poster'); ?></li>
                                             <li><?php _e('Ask the reader if they’ve ever encountered X problem that your post solves.', 'evergreen-content-poster'); ?></li>
                                             <li><?php _e('Post an interesting piece of data or a statistic that you bring up as part of the source information for your post.', 'evergreen-content-poster'); ?></li>
                                             <li><?php _e('Send an @mention to an influencer you mention or link to in your post, but use the mention later in the tweet so it’s a public tweet.', 'evergreen-content-poster'); ?></li>
                                          </ul>

                                          <p class="ecp-metabox-p"><?php _e('We bet you can come up with many more ideas yourself. Start by adding them to your library below.', 'evergreen-content-poster'); ?></p>
                                          <?php if (!$token) { ?>
                                             <p class="ecp-metabox-p"><em><?php echo sprintf(
                                                                              /* translators: %1s is the opening link tag and %2s is the closing link tag */
                                                                              esc_html__('Before you can add any content though, you first have to %1sconnect your social profiles%2s.', 'evergreen-content-poster'),
                                                                              '<a href="' . esc_url(admin_url('admin.php?page=evergreen-content-settings#AccountSettings')) . '" class="ecp-metabox-p">',
                                                                              '</a>'
                                                                           ); ?></em></p>
                                          <?php } ?>
                                       </div>

                                       <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-network-container">
                                          <div class="ecp-grid-right ecp-col-220 ecp-profile-dropdown">
                                             <a href="javascript:void(0)" class="ecp-col-940 button ecp-navy-button ecp-show-profiles ecp-padding-5" <?php if (!$token) { ?> disabled="true" <?php } ?>><?php _e('Add one more post', 'evergreen-content-poster'); ?> <span class="ecp-grid-right dashicons dashicons-arrow-down-alt2"></span></a>
                                             <ul class="ecp-network-list">
                                                <?php foreach ($profiles as $service => $profile_list) { ?>
                                                   <?php foreach ($profile_list as $key => $single_profile) {
                                                      $avatar = EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png';
                                                      $permalink = get_permalink($post_item['ID']);

                                                      if (!empty($single_profile->avatar))
                                                         $avatar = $single_profile->avatar;

                                                      $profile_username = !empty($single_profile->formatted_username) ? $single_profile->formatted_username : strtolower($single_profile->service_type) . ($key + 1);
                                                      if (strlen($profile_username) > 18) {
                                                         $profile_username = substr($profile_username, 0, 15) . '...';
                                                      }

                                                      $service_type = ucwords($single_profile->service . ' ' . strtolower($single_profile->service_type));
                                                      if (strlen($service_type) > 17) {
                                                         $service_type = substr($service_type, 0, 14) . '...';
                                                      }

                                                      $setting = $settings;
                                                      if (isset($setting['utm_tags']) && $setting['utm_tags'] === 'Y') {
                                                         $link = trim($permalink, '/') . '?utm_source=' . str_replace(' ', '', $single_profile->formatted_service) . '&utm_medium=social&utm_campaign=Evergreen%20Content%20Poster';
                                                      } else {
                                                         $link = trim($permalink, '/');
                                                      }

                                                      if ($single_profile->service === 'twitter') {
                                                         $length = 0;
                                                      } else {
                                                         $length = strlen($link) + 1;
                                                      }
                                                   ?>
                                                      <li>
                                                         <div class="ecp-grid ecp-col-940">
                                                            <a href="javascript:void(0)" data-url="<?php echo $link ?>" data-urllength="<?php echo $length ?>" data-username="<?php echo $single_profile->formatted_username; ?>" data-profile="<?php echo $single_profile->id; ?>" data-formatted-service="<?php echo $single_profile->formatted_username . ' ' . $single_profile->formatted_service; ?>" data-service="<?php echo strtolower($single_profile->service) . '-' . strtolower($single_profile->service_type); ?>" data-avatar="<?php echo $avatar; ?>" data-network="<?php echo strtolower($single_profile->service); ?>" class="button ecp-network-single">
                                                               <div class="ecp-connected-profilex">
                                                                  <div class="ecp-connected-profile-avatar">
                                                                     <img class="ecp-profile-circle-medium" ng-src="<?php echo $avatar; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $avatar; ?>" />
                                                                     <div class="ecp-social-network-icon-medium ecp-<?php echo strtolower($single_profile->service); ?>"></div>
                                                                     <span class="ecp-connected-profile-network"><?php _e($service_type, 'evergreen-content-poster'); ?></span>
                                                                  </div>
                                                               </div>
                                                            </a>
                                                         </div>
                                                      </li>
                                                <?php
                                                   } // end foreach ($profile_list as $key => $single_profile)
                                                   unset($single_profile);
                                                } // end foreach ($profiles as $service => $profile_list)
                                                ?>
                                             </ul>
                                          </div>
                                       </div>
                                    </div>

                                    <hr class="ecp-section ecp-grid ecp-col-940" />
                                    <div class="add-new-ecp-post"></div>
                                    <div id="ecp-saved-posts-block" class="ecp-col-940 ecp-grid ecp-saved-posts-block-popup">
                                       <?php
                                       $count = 1;
                                       $ecp_saved_posts = new WP_Query([
                                          'post_type' => ['ecp-posts'],
                                          'posts_per_page' => -1,
                                          'meta_query' => [
                                             [
                                                'key' => 'ecp-post-ref',
                                                'value' => sanitize_text_field($post_item['ID']),
                                             ],
                                          ],
                                          'orderby' => 'ID',
                                          'order' => 'DESC',
                                       ]);

                                       foreach ($ecp_saved_posts->posts as $key => $post_ecp) {
                                          $ecp_image = get_post_meta($post_ecp->ID, 'ecp-post-media', true);
                                          $ecp_profile = get_post_meta($post_ecp->ID, 'ecp-post-profile', true);
                                          $ecp_network = get_post_meta($post_ecp->ID, 'ecp-post-network', true);
                                          $ecp_category_id = get_post_meta($post_ecp->ID, 'ecp-post-category', true);
                                          $ecp_post_ref = get_post_meta($post_ecp->ID, 'ecp-post-ref', true);

                                          $network_profiles = (array) $profiles;

                                          $category = new stdClass();
                                          if ($ecp_category_id) {
                                             $category = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}evergreen_categories WHERE id = ${ecp_category_id}");
                                          }

                                          $selected_profile = new stdClass();
                                          foreach ($network_profiles as $profile) {
                                             foreach ($profile as $single_profile) {
                                                if ($ecp_profile === $single_profile->id) {
                                                   $selected_profile = $single_profile;
                                                }
                                             } // end foreach ($profile as $single_profile)
                                          } // end foreach ($network_profiles as $profile)

                                          // fix error when ecp-post-network meta value does not exist in current installation
                                          if (is_null($ecp_network) || !array_key_exists($ecp_network, $network_profiles) || empty((array) $selected_profile)) continue;
                                       ?>
                                          <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-content-container ecp-post-saved-template" id="ecp_post_<?php echo $post_ecp->ID; ?>">
                                             <input type="hidden" class="ecp-post-id" value="<?php echo $post_ecp->ID; ?>" />
                                             <input type="hidden" class="ecp-post-ref" value="<?php echo $ecp_post_ref; ?>" />
                                             <input type="hidden" class="saved-category-id" value="<?php echo $category ? $category->id : 0; ?>" />
                                             <div class="ecp-grid ecp-col-620 content-show" style="margin-bottom: 0;">

                                                <?php foreach ($network_profiles[$ecp_network] as $single_profile) {
                                                   if ($ecp_profile !== $single_profile->id) continue;

                                                   $avatar = EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png';
                                                   if (!empty($single_profile->avatar))
                                                      $avatar = $single_profile->avatar;

                                                   $history_post_daily = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}evergreen_content_logs WHERE post_id = " . $post_ecp->ID . " AND result = 'success' ORDER BY request_sent DESC LIMIT 1");
                                                   $social_name = $selected_profile->formatted_username . ' ' . $selected_profile->formatted_service;
                                                ?>
                                                   <div class="ecp-section ecp-grid ecp-col-940">
                                                      <div class="ecp-grid ecp-col-780">
                                                         <?php if (!empty((array) $history_post_daily)) { ?>
                                                            <p class="ecp-post-last-shared">
                                                               <?php echo sprintf(
                                                                  /* translators: %1s is the name of a social network e.g. Facebook Page %2s is the time it was shared */
                                                                  esc_html__('Last shared to your %1s at %2s', 'evergreen-content-poster'),
                                                                  $single_profile->formatted_username . ' ' . $single_profile->formatted_service,
                                                                  date('M d, Y H:i:s', strtotime($history_post_daily->request_sent))
                                                               ); ?>
                                                            </p>
                                                            <?php if ($category) { ?> - <span class="category-name"><?php echo $category->name ?></span> <?php } ?>
                                                         <?php } else { ?>
                                                            <p class="ecp-post-last-shared">
                                                               <?php echo sprintf(
                                                                  /* translators: %s is the name of a social network e.g. Facebook */
                                                                  esc_html__('Not shared to your %s yet', 'evergreen-content-poster'),
                                                                  $single_profile->formatted_service
                                                               ); ?>
                                                            </p>
                                                            <?php if ($category) { ?> <span class="category-name"><?php echo $category->name ?></span> <?php } ?>
                                                         <?php } ?>
                                                      </div>
                                                      <div class="ecp-grid ecp-col-10">
                                                         <div class="ecp-connected-profile-avatar" style="padding-top: 15px;">
                                                            <img class="ecp-profile-circle-small" ng-src="<?php echo $avatar; ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $avatar; ?>" />
                                                            <div class="ecp-social-network-icon-small ecp-<?php echo strtolower($ecp_network); ?>"></div>
                                                         </div>
                                                      </div>
                                                      <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                         <div class="ecp-dropdown">
                                                            <a href="#" class="ecp-post-action ecp-dropdown-share ecp-dropbtn"><span class="dashicons dashicons-share"></span></a>
                                                            <div class="ecp-my-dropdown ecp-dropdown-content">
                                                               <a href="#" class="ecp-share-now-action" data-id="<?php echo $post_ecp->ID ?>" data-content="<?php echo sanitize_textarea_field(stripslashes_deep($post_ecp->post_content)) ?>" data-image="<?php echo $ecp_image ?>" data-social-name="<?php echo $social_name ?>"><?php _e('Share now', 'evergreen-content-poster') ?></a>
                                                               <a href="#" class="ecp-add-queue-action" data-id="<?php echo $post_ecp->ID ?>" data-content="<?php echo sanitize_textarea_field(stripslashes_deep($post_ecp->post_content)) ?>" data-image="<?php echo $ecp_image ?>" data-social-name="<?php echo $social_name ?>"><?php _e('Add to queue', 'evergreen-content-poster') ?></a>
                                                            </div>
                                                         </div>
                                                      </div>
                                                      <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                         <a href="#" class="ecp-post-action ecp-post-edit">
                                                            <span class="dashicons dashicons-edit-page"></span>
                                                         </a>
                                                      </div>
                                                      <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                                         <a href="#" class="ecp-post-action ecp-post-delete">
                                                            <span class="dashicons dashicons-trash"></span>
                                                         </a>
                                                      </div>
                                                   </div>
                                                <?php } // end foreach ($network_profiles[$ecp_network] as $single_profile)
                                                unset($single_profile);
                                                ?>
                                                <div class="ecp-section ecp-grid ecp-col-940 ecp-post-text">
                                                   <p class="ecp-post-content"><span class="ecp-post-content-show"><?php echo sanitize_textarea_field(stripslashes_deep($post_ecp->post_content)) ?></span></p>
                                                </div>
                                             </div>
                                             <div class="ecp-grid ecp-col-620 content-edit hidden" style="margin-bottom: 0px;">
                                                <div class="ecp-section ecp-grid ecp-col-940">
                                                   <div class="ecp-grid ecp-col-855" style="margin-bottom: 0">
                                                      <?php if (!empty((array) $history_post_daily)) { ?>
                                                         <p class="ecp-post-last-shared">
                                                            <?php echo sprintf(
                                                               /* translators: %1s is the name of a social network e.g. Facebook Page %2s is the time it was shared */
                                                               esc_html__('Last shared to your %1s at %2s', 'evergreen-content-poster'),
                                                               $selected_profile->formatted_username . ' ' . $selected_profile->formatted_service,
                                                               date('M d, Y H:i:s', strtotime($history_post_daily->request_sent))
                                                            ); ?>
                                                         </p>
                                                         <span class="category-name"><?php echo $category->name ?></span>
                                                      <?php } else { ?>
                                                         <p class="ecp-post-last-shared">
                                                            <?php echo sprintf(
                                                               /* translators: %s is the name of a social network e.g. Facebook Page */
                                                               esc_html__('Not shared to your %s yet', 'evergreen-content-poster'),
                                                               $selected_profile->formatted_service
                                                            ); ?>
                                                         </p>
                                                         <span class="category-name"><?php echo $category->name ?></span>
                                                      <?php } ?>
                                                   </div>
                                                </div>

                                                <?php
                                                switch ($selected_profile->service) {
                                                   case 'facebook':
                                                      $limit = EVERGREEN_CONTENT_POSTER_FACEBOOK_POST_LENGTH;
                                                      break;
                                                   case 'instagram':
                                                      $limit = EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH;
                                                      break;
                                                   case 'linkedin':
                                                      $limit = EVERGREEN_CONTENT_POSTER_LINKEDIN_PROFILE_POST_LENGTH;
                                                      break;
                                                   case 'pinterest':
                                                      $limit = EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH;
                                                      break;
                                                   case 'twitter':
                                                      $limit = EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH_POST;
                                                      break;
                                                   case 'googlebusiness':
                                                      $limit = EVERGREEN_CONTENT_POSTER_GOOGLE_BUSINESS_PROFILE_POST_LENGTH;
                                                      break;
                                                   case 'tiktok':
                                                      $limit = EVERGREEN_CONTENT_POSTER_TIK_TOK_POST_LENGTH;
                                                      break;
                                                   default:
                                                      $limit = 600;
                                                      break;
                                                }

                                                $setting = $this->common->general_settings();
                                                if (isset($setting['utm_tags']) && $setting['utm_tags'] === 'Y') {
                                                   $link = trim($permalink, '/') . '?utm_source=' . str_replace(' ', '', $selected_profile->formatted_service) . '&utm_medium=social&utm_campaign=Evergreen%20Content%20Poster';
                                                } else {
                                                   $link = trim($permalink, '/');
                                                }

                                                if ($selected_profile->service === 'twitter') {
                                                   $length = 0;
                                                } else {
                                                   $length = strlen($link) + 1;
                                                }
                                                ?>
                                                <div class="ecp-input" style="top: -25px; position: relative;">
                                                   <div class="area-content-box">
                                                      <div class="ecp-countdown ecp-blue"><span class="counterNumber"><?php if (empty($ecp_image) || $selected_profile->service === 'twitter') {
                                                                                                                           echo $limit - strlen($post_ecp->post_content);
                                                                                                                        } else {
                                                                                                                           echo $limit - strlen($post_ecp->post_content) - $length;
                                                                                                                        } ?></span></div>
                                                      <textarea data-network="<?php echo $selected_profile->service ?>" rows="3" data-counter="<?php echo $limit ?>" data-length="<?php if (empty($ecp_image) || $selected_profile->service === 'twitter') {
                                                                                                                                                                                       echo $limit - strlen($post_ecp->post_content);
                                                                                                                                                                                    } else {
                                                                                                                                                                                       echo $limit - strlen($post_ecp->post_content) - $length;
                                                                                                                                                                                    } ?>" class="ecp-post-content area-content ecp-service-post-text-library text-content-<?php echo $post_ecp->ID ?>" data-id="<?php echo $post_ecp->ID ?>" style="min-height: unset"><?php echo sanitize_textarea_field(stripslashes_deep($post_ecp->post_content)) ?></textarea>
                                                   </div>
                                                </div>
                                                <select name="ecp-category-library" value="<?php echo $ecp_category_id ?>" class="ecp-admin-input ecp-category-library">
                                                   <?php if (count($allCategories) > 0) {
                                                      foreach ($allCategories as $category) { ?>
                                                         <option value="<?php echo $category->id ?>" <?php if ($category->id === $ecp_category_id) { ?> selected <?php } ?>><?php echo $category->name ?></option>
                                                   <?php } // end foreach ($allCategories as $category)
                                                   } ?>
                                                </select>
                                                <a href="#" id="add-row-<?php echo $post_ecp->ID ?>" class="button ecp-navy-button change-post-in-library" style="margin-top: -10px" data-id="<?php echo $post_ecp->ID ?>"><?php _e('Save changes', 'evergreen-content-poster'); ?></a>
                                                <a href="#" class="ecp-button cancel-change" style="margin-top: -10px; margin-right: 20px!important; cursor: pointer" data-id="<?php echo $post_ecp->ID ?>"><?php _e('Cancel', 'evergreen-content-poster'); ?></a>
                                             </div>

                                             <div class="ecp-grid ecp-col-300 ecp-post-img-bg" style="margin-bottom: 0px;height: 246px">
                                                <?php if (!empty($ecp_image)) { ?>
                                                   <img class="ecp-post-image-display" src="<?php echo get_post_meta($post_ecp->ID, 'ecp-post-media', true); ?>" />
                                                <?php } else if( 'googlebusiness' == $selected_profile->service || 'instagram' == $selected_profile->service ) { ?>
                                                   <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached-mandatory.png" />
                                                <?php } else if( 'tiktok' == $selected_profile->service ) { ?>
                                                   <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-video-attached-mandatory.png" />
                                                <?php } else { ?>
                                                   <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached.png" />
                                                <?php } ?>
                                                <div class="ecp-image-overlay"></div>
                                                <div class="ecp-image-actions">
                                                   <a href="#" class="ecp-image-edit ecp-edit-media" title="" target="_blank">
                                                      <label for="wp_uploadfile_new_<?php echo $post_ecp->ID ?>" data-id="<?php echo $post_ecp->ID ?>"><span class="dashicons dashicons-edit"></span></label>
                                                      <input id="wp_uploadfile_new_<?php echo $post_ecp->ID ?>" data-id="<?php echo $post_ecp->ID ?>" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                                      <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                                   </a>
                                                   <?php if ($selected_profile->service !== 'instagram' && $selected_profile->service !== 'pinterest') { ?>
                                                      <a href="#" class="ecp-image-delete ecp-remove-media ecp-image-delete-add-media-saved <?php if (empty($ecp_image)) { ?> hidden <?php } ?>" title="">
                                                         <span class="dashicons dashicons-no-alt"></span>
                                                      </a>
                                                   <?php } ?>
                                                   <input type="hidden" class="url-plugin" value="<?php echo EVERGREEN_CONTENT_POSTER_PATH ?>">
                                                   <input type="hidden" class="is_image" value="<?php if (empty($ecp_image)) {
                                                                                                   echo 0;
                                                                                                } else {
                                                                                                   echo 1;
                                                                                                } ?>">
                                                   <input type="hidden" class="url-length" value="<?php echo $length ?>">
                                                   <input type="hidden" class="ecp-network" value="<?php echo $selected_profile->service ?>">
                                                </div>
                                             </div>
                                          </div>
                                       <?php } // end foreach ($ecp_saved_posts->posts as $key => $post_ecp)
                                       ?>
                                    </div>
                                 </div>
                              </div>
                              <!-- end add evergreen content block -->

                           </div>
                        <?php } // end foreach($recent_posts as $post_item)
                        ?>
                        <div class="ecp-fields-base ecp-hidden">
                           <div class="ecp-fields-template ecp-post-fields-container ecp-grid ecp-col-940">
                              <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting">
                                 <div class="ecp-hidden ecp-profile-data" data-avatar="" data-network=""></div>
                                 <div id="repeatable-fieldset">
                                    <div id="evergreen-content-poster" class="ecp-new-data-row active-row" rel="1">
                                       <div class="ecp-td">
                                          <span class="ecp-input-title"><?php _e('Evergreen Content', 'evergreen-content-poster'); ?></span><br /><br />
                                          <div class="ecp-input" style="top: -25px; position: relative;">
                                             <div class="ecp-countdown ecp-blue"><span class="counterNumber">256</span></div>
                                             <textarea name="egcontent[]" cols="60" rows="6" placeholder="<?php _e('Write your awesome custom content here...', 'evergreen-content-poster'); ?>" id="ecp_custom_message" class="ecp-textarea large-text  ecp-service-post-text" name="ecp_custom_mesage" style="border-top-right-radius: 0px;" spellcheck="false"></textarea>
                                             <input type="hidden" class="url-plugin" value="<?php echo EVERGREEN_CONTENT_POSTER_PATH ?>">
                                          </div>
                                          <p class="ecp-posttext-info"></p>
                                       </div>
                                    </div>
                                 </div>
                              </div>

                              <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-posts-form-bottom-block">
                                 <div class="ecp-grid ecp-col-300">
                                    <p class="ecp-input-label" style="padding-left: 0;"><?php _e('Evergreen Content Category', 'evergreen-content-poster'); ?></p>
                                    <p class="description"><?php _e('Select the category for this post, or leave for default', 'evergreen-content-poster'); ?></p>
                                 </div>
                                 <div class=" ecp-grid ecp-col-300 ecp-grid-right">
                                    <select style="margin-top: 1rem!important" name="ecp_category" value="" class="ecp-admin-input ecp_category ecp_category_select" data-ref="ecp_categories" aria-invalid="false">
                                       <?php if (count($allCategories) > 0) {
                                          foreach ($allCategories as $category) { ?>
                                             <option value="<?php echo $category->id ?>"><?php echo $category->name ?></option>
                                       <?php } // end foreach ($allCategories as $category)
                                       } ?>
                                    </select>
                                 </div>
                              </div>

                              <div class="ecp-grid ecp-col-940 ecp-option-container ecp-field-setting ecp-posts-form-bottom-block">
                                 <div class="ecp-grid ecp-col-460">
                                    <span class="ecp-input-title"><?php _e('Evergreen Content Share Image', 'evergreen-content-poster'); ?></span><br />
                                    <div class="ecp-upload-custom config-upload">
                                       <div class="ecp-grid ecp-col-620 ecp-post-img-bg hidden upload-image-new" style="margin-bottom: 0;height: 246px">
                                          <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached.png" />
                                          <div class="ecp-image-overlay"></div>
                                          <div class="ecp-image-actions">
                                             <a href="#" class="ecp-image-edit ecp-edit-media" title="" target="_blank">
                                                <label for="wp_uploadfile_new"><span class="dashicons dashicons-edit"></span></label>
                                                <input id="wp_uploadfile_new" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                                <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                             </a>
                                             <a href="#" class="ecp-image-delete ecp-remove-media ecp-image-delete-add-media" title="">
                                                <span class="dashicons dashicons-no-alt"></span>
                                             </a>
                                          </div>
                                       </div>
                                       <div class="upload-image-old">
                                          <div class="ecp-image-upload">
                                             <label for="wp_uploadfile" class="ecp-label-btn label-custom"><?php _e('Add Media', 'evergreen-content-poster'); ?></label>
                                             <input id="wp_uploadfile" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                             <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                          </div>
                                          <p class="ecp-postimage-info"></p>
                                       </div>
                                    </div>
                                    <input type="hidden" class="is_image" value="0">
                                 </div>

                                 <div class="ecp-grid ecp-col-460 ecp-grid-right ecp-add-library-item">
                                    <div class="ecp-grid-right">
                                       <button id="add-row" class="button ecp-navy-button ecp-add-post"><?php _e('Add Item to Library', 'evergreen-content-poster'); ?></button>
                                    </div>
                                    <div class="ecp-grid-right">
                                       <button id="cancel" class="button ecp-default-button ecp-cancel-add-post ecp-cancel-without-popup"><?php _e('Cancel', 'evergreen-content-poster'); ?></button>
                                       <a style="margin-top: 3rem!important; margin-bottom: 0!important;" href="#confirm-cancel-modal" rel="modal:open" class="button ecp-default-button ecp-hidden ecp-cancel-with-popup"><?php _e('Cancel', 'evergreen-content-poster'); ?></button></a>
                                    </div>
                                 </div>

                                 <div id="confirm-cancel-modal" class="modal all-modal">
                                    <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Do you really want to stop adding this item to your library?', 'evergreen-content-poster'); ?></p>
                                    <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-cancel-add-post jquery-modal-close"><?php _e('Ok', 'evergreen-content-poster'); ?></a>
                                    <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster') ?></a>
                                 </div>
                                 <input type="hidden" class="url-plugin" value="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>">
                                 <input type="hidden" class="ecp-social-name-add-post" value="">
                              </div>
                           </div>
                        </div>
                        <div class="ecp-hidden ecp-posttext-texts">
                           <p class="ecp-posttext facebook-page" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_FACEBOOK_POST_LENGTH; ?>"><?php _e('Based on the current content above your Facebook Page Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext facebook-group" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_FACEBOOK_GROUP_POST_LENGTH; ?>"><?php _e('Based on the current content above your Facebook Group Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext instagram" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH; ?>"><?php _e('Based on the current content above your Instagram Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext instagram-business" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH; ?>"><?php _e('Based on the current content above your Instagram Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext linkedin-profile" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_LINKEDIN_PROFILE_POST_LENGTH; ?>"><?php _e('Based on the current content above your LinkedIn Personal Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext linkedin-page" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_LINKEDIN_PAGE_POST_LENGTH; ?>"><?php _e('Based on the current content above your LinkedIn Page Post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext pinterest" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH; ?>"><?php _e('Based on the current content above your Pinterest Pin description has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext pinterest-board" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH; ?>"><?php _e('Based on the current content above your Pinterest Pin description has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext twitter-profile" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH; ?>"><?php _e('Based on a link being added, and the current content above your tweet has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext googlebusiness-business" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_GOOGLE_BUSINESS_PROFILE_POST_LENGTH; ?>"><?php _e('Based on a link being added, and the current content above your Google Business Profile post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?><?php _e('However, even though it’s nice of Google to give so much space to work with, the ideal length for any given post falls between 150-300 characters.', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext tiktok-profile" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_TIK_TOK_POST_LENGTH; ?>"><?php _e('Based on the current content above your TikTok post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-posttext mastodon-profile" data-limit="<?php echo EVERGREEN_CONTENT_POSTER_MASTODON_POST_LENGTH; ?>"><?php _e('Based on the current content above your Mastodon post has', 'evergreen-content-poster'); ?> <span class="post-limit"></span> <?php _e('characters remaining', 'evergreen-content-poster'); ?></p>
                        </div>
                        <div class="ecp-hidden ecp-postimage-texts">
                           <?php // whichever network is chosen to post to, one of the below messages needs to be shown
                           ?>
                           <p class="ecp-postimage facebook-page"><?php _e('Add an image that is optimized for maximum exposure on your Facebook page. We recommend using either the size of a Facebook Page Photo (940x788) or a Facebook Link Post (1200x628).', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage facebook-group"><?php _e('Add an image that is optimized for maximum exposure in Facebook Groups. We recommend using the size of a Facebook Group Photo (640x334).', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage instagram"><?php _e('Add an image that is optimized for maximum exposure on Instagram. We recommend using the size of an Instagram Photo (1080x1080) or a Facebook Link Post (1200x628).', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage instagram-business"><?php _e('Add an image that is optimized for maximum exposure on Instagram. We recommend using the size of an Instagram Photo (1080x1080) or a Facebook Link Post (1200x628).', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage linkedin-profile"><?php _e('Add an image that is optimized for maximum exposure on your LinkedIn profile. We recommend using the size of a LinkedIn Photo (1400x800).', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage linkedin-page"><?php _e('Add an image that is optimized for maximum exposure on your LinkedIn page. We recommend using the size of a LinkedIn Page Photo (1400x800).', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage pinterest"><?php _e('Add one or more images that are optimized for maximum exposure on Pinterest. We recommend using an image that is formatted in a 2:3 aspect ratio like 1000 x 1500.', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage pinterest-board"><?php _e('Add one or more images that are optimized for maximum exposure on Pinterest. We recommend using an image that is formatted in a 2:3 aspect ratio like 1000 x 1500.', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage twitter-profile"><?php _e('Add an image that is optimized for maximum exposure on Twitter. We recommend using an image that is formatted in 16:9 aspect ratio like 1200x675.', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage googlebusiness-business"><?php _e('Add an image that is optimized for maximum exposure on your Google Business Profile post. We recommend using an image that is formatted in 4:3 aspect ratio with a minimum resolution of 480x270.', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage tiktok-profile"><?php _e('Add an video that is optimized for maximum exposure on your TikTok post. We recommend using an video that is formatted in 9:16 aspect ratio with a minimum resolution of 1080x1920. It needs to be in MP4 or MOV format with a maximum length of 180 seconds. For Android users, the maximum video file size is 72MB. If you\'re using an iPhone, the maximum video file size is 287.6MB', 'evergreen-content-poster'); ?></p>
                           <p class="ecp-postimage mastodon-profile"><?php _e('Add an image that is optimized for maximum exposure on Mastodon. We recommend using an image that is formatted in 1:1 aspect ratio. Ideally in a resolution that is 1280x1280px.', 'evergreen-content-poster'); ?></p>
                        </div>

                        <div class="ecp-hidden ecp-post-saved-base">
                           <div class="ecp-section ecp-grid ecp-col-940 ecp-fit ecp-content-container ecp-post-saved-template">
                              <input type="hidden" class="ecp-post-id" value="" />
                              <input type="hidden" class="ecp-service" value="" />
                              <input type="hidden" class="ecp-post-ref" value="" />
                              <input type="hidden" class="saved-category-id" value="" />
                              <div class="ecp-grid ecp-col-620 content-show" style="margin-bottom: 0;">
                                 <div class="ecp-section ecp-grid ecp-col-940">
                                    <div class="ecp-grid ecp-col-780">
                                       <p class="ecp-post-last-shared"><?php echo sprintf(
                                                                           /* translators: %s is the name of the social network - e.g. '<company name> Twitter' */
                                                                           esc_html__('Not shared to your %s yet', 'evergreen-content-poster'),
                                                                           '<span class="network_name"></span>'
                                                                        ); ?>
                                       </p>
                                       <span class="category-name"></span>
                                    </div>
                                    <div class="ecp-grid ecp-col-10">
                                       <div class="ecp-connected-profile-avatar" style="padding-top: 15px;">
                                          <img class="ecp-profile-circle-small" ng-src="<?php echo $avatar ?? (EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'); ?>" img-src-fallback="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-profile-unknown.png" src="<?php echo $avatar ?? (EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png'); ?>" />
                                          <div class="ecp-social-network-icon-small ecp-twitter"></div>
                                       </div>
                                    </div>
                                    <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                       <div class="ecp-dropdown">
                                          <a href="#" class="ecp-post-action ecp-dropdown-share ecp-dropbtn"><span class="dashicons dashicons-share"></span></a>
                                          <div class="ecp-my-dropdown ecp-dropdown-content">
                                             <a href="#" class="ecp-share-now-action" data-id="" data-content="" data-image="" data-social-name=""><?php _e('Share now', 'evergreen-content-poster') ?></a>
                                             <a href="#" class="ecp-add-queue-action" data-id="" data-content="" data-image="" data-social-name=""><?php _e('Add to queue', 'evergreen-content-poster') ?></a>
                                          </div>
                                       </div>
                                    </div>
                                    <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                       <a href="#" class="ecp-post-action ecp-post-edit">
                                          <span class="dashicons dashicons-edit-page"></span>
                                       </a>
                                    </div>
                                    <div class="ecp-grid ecp-col-10" style="padding-top: 15px;">
                                       <a href="#" class="ecp-post-action ecp-post-delete">
                                          <span class="dashicons dashicons-trash"></span>
                                       </a>
                                    </div>
                                 </div>
                                 <div class="ecp-section ecp-grid ecp-col-940 ecp-post-text">
                                    <p class="ecp-post-content"><span class="ecp-post-content-show"></span></p>
                                 </div>
                              </div>
                              <div class="ecp-grid ecp-col-620 content-edit hidden" style="margin-bottom: 0px;">
                                 <div class="ecp-section ecp-grid ecp-col-940">
                                    <div class="ecp-grid ecp-col-855" style="margin-bottom: 0">
                                       <p class="ecp-post-last-shared"><?php echo sprintf(
                                                                           /* translators: %s is the name of the social network - e.g. '<company name> Twitter' */
                                                                           esc_html__('Not shared to your %s yet', 'evergreen-content-poster'),
                                                                           '<span class="network_name"></span>'
                                                                        ); ?></p>
                                       <span class="category-name"></span>
                                    </div>
                                 </div>

                                 <div class="ecp-input" style="top: -25px; position: relative;">
                                    <div class="area-content-box">
                                       <div class="ecp-countdown ecp-blue"><span class="counterNumber"></span></div>
                                       <textarea data-network="" rows="3" data-counter="" class="ecp-post-content area-content ecp-service-post-text-library" data-id="" data-length="" style="min-height: unset"></textarea>
                                    </div>
                                 </div>
                                 <select name="ecp-category-library" value="" class="ecp-admin-input ecp-category-library ecp_category_select" aria-invalid="false">
                                    <?php if (count($allCategories) > 0) {
                                       foreach ($allCategories as $category) { ?>
                                          <option value="<?php echo $category->id ?>"><?php echo $category->name ?></option>
                                    <?php } // end foreach ($allCategories as $category)
                                    } ?>
                                 </select>
                                 <a href="#" class="button ecp-navy-button change-post-in-library" style="margin-top: -10px" data-id=""><?php _e('Save changes', 'evergreen-content-poster'); ?></a>
                                 <a href="#" class="ecp-button cancel-change" style="margin-top: -10px; margin-right: 20px!important; cursor: pointer" data-id=""><?php _e('Cancel', 'evergreen-content-poster'); ?></a>
                              </div>

                              <div class="ecp-grid ecp-col-300 ecp-post-img-bg" style="margin-bottom: 0px;height: 246px">
                                 <img class="ecp-post-image-display" src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-no-visual-attached.png" />
                                 <div class="ecp-image-overlay"></div>
                                 <div class="ecp-image-actions">
                                    <a href="#" class="ecp-image-edit ecp-edit-media" title="" target="_blank">
                                       <label for="" data-id=""><span class="dashicons dashicons-edit"></span></label>
                                       <input id="" data-id="" type="file" class="ecp-fileinput" name="egpostattachement[]" value="" />
                                       <input class="ecp-post-image" data-profile="" type="hidden" name="ecp_post_image" value="" />
                                    </a>
                                    <a href="#" class="ecp-image-delete ecp-remove-media ecp-image-delete-add-media-saved" title="">
                                       <span class="dashicons dashicons-no-alt"></span>
                                    </a>
                                    <input type="hidden" class="url-plugin" value="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>">
                                    <input type="hidden" class="is_image" value="">
                                    <input type="hidden" class="url-length" value="<?php echo $length ?? '' ?>">
                                 </div>
                              </div>
                           </div>
                        </div>

                        <div class="ecp-grid-right">
                           <a href="#" class="button ecp-green-button ecp-next" data-step="4" style="color:#1b3a51; font-weight: 600;"><?php _e('next', 'evergreen-content-poster'); ?></a>
                        </div>
                        <div class="ecp-grid">
                           <a href="#" class="button ecp-grey-button ecp-previous" data-step="4" style="font-weight: 600;"><?php _e('previous', 'evergreen-content-poster'); ?></a>
                        </div>

                        <input type="hidden" name="ecp-post-ref" id="ecp-post-ref" value="" />
                        <input type="hidden" name="url-length" id="url-length" value="" />

                     </div> <!-- end step 4 -->

                     <!-- step 5 -->
                     <div id="step-5" class="step-content">
                        <h2 style="text-align: center;"><?php _e('Optional step 5: Getting to know your business', 'evergreen-content-poster'); ?></h2>
                        <p><?php _e('This step is optional and if you want you can skip and go straight to the next step, but we would like to get to know you a little bit better.', 'evergreen-content-poster'); ?></p>
                        <p><?php _e('By better knowing what types of people or what type of businesses use the Evergreen Content Poster, we can better tailor the plugin to help solve your needs.', 'evergreen-content-poster'); ?></p>

                        <label class="hidden label-solopreneur-option"><?php _e('What type of entrepreneur are you?', 'evergreen-content-poster'); ?></label>
                        <label class="hidden label-small-medium-option"><?php _e('What kind of small & medium business do you have or do you work at?', 'evergreen-content-poster'); ?></label>
                        <label class="hidden label-agency-option"><?php _e('What kind of agency do you have or do you work at?', 'evergreen-content-poster'); ?></label>
                        <div class="type-business">
                           <p><strong><?php _e('Can you tell us which type of business best represents you?', 'evergreen-content-poster'); ?></strong></p>
                           <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type'] === 'Solopreneur') { ?> ecp-selected <?php } ?>" data-type="solopreneur-option" data-value="Solopreneur">
                              <a href="#" class="ecp-category-title--link">
                                 <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-onboading-solopreneur.svg" class="ecp-category-title--image" />
                                 <h3 class="ecp-category-title"><?php _e('Solopreneur', 'evergreen-content-poster'); ?></h3>
                              </a>
                           </div>

                           <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type'] === 'Small & Medium Business') { ?> ecp-selected <?php } ?>" data-type="small-medium-option" data-value="Small & Medium Business">
                              <a href="#" class="ecp-category-title--link">
                                 <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-onboarding-small-medium-business.svg" class="ecp-category-title--image" />
                                 <h3 class="ecp-category-title"><?php _e('Small & Medium Business', 'evergreen-content-poster'); ?></h3>
                              </a>
                           </div>

                           <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type'] === 'Agency') { ?> ecp-selected <?php } ?>" data-type="agency-option" data-value="Agency">
                              <a href="#" class="ecp-category-title--link">
                                 <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-onboarding-agency.svg" class="ecp-category-title--image" />
                                 <h3 class="ecp-category-title"><?php _e('Agency', 'evergreen-content-poster'); ?></h3>
                              </a>
                           </div>
                        </div>

                        <div class="ecp-clearfix"></div>

                        <div class="entrepreneur <?php if (!$step5['business_type']) { ?> hidden <?php } ?>">
                           <p><strong><?php _e('What type of entrepreneur are you?', 'evergreen-content-poster'); ?></strong></p>
                           <div class="solopreneur-option <?php if ($step5['business_type'] !== 'Solopreneur') { ?> hidden <?php } ?> ecp-entrepreneur">
                              <!-- Solopreneur options -->
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Freelancer') { ?> ecp-selected <?php } ?>" data-entrepreneur="freelancer" data-value="Freelancer">
                                 <h3 class="ecp-category-title"><?php _e('Freelancer', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Author or speaker') { ?> ecp-selected <?php } ?>" data-entrepreneur="author_or_speaker" data-value="Author or speaker">
                                 <h3 class="ecp-category-title"><?php _e('Author or speaker', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Coach') { ?> ecp-selected <?php } ?>" data-entrepreneur="coach" data-value="Coach">
                                 <h3 class="ecp-category-title"><?php _e('Coach', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Blogger') { ?> ecp-selected <?php } ?>" data-entrepreneur="blogger" data-value="Blogger">
                                 <h3 class="ecp-category-title"><?php _e('Blogger', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Other (Solopreneur)') { ?> ecp-selected <?php } ?>" data-entrepreneur="other_solopreneur" data-value="Other (Solopreneur)">
                                 <h3 class="ecp-category-title"><?php _e('Other (Solopreneur)', 'evergreen-content-poster'); ?></h3>
                              </div>
                           </div>
                           <div class="small-medium-option <?php if ($step5['business_type'] !== 'Small & Medium Business') { ?> hidden <?php } ?> ecp-entrepreneur">
                              <!-- Small & Medium Business options -->
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'eCommerce') { ?> ecp-selected <?php } ?>" data-entrepreneur="ecommerce" data-value="eCommerce">
                                 <h3 class="ecp-category-title"><?php _e('eCommerce', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Startup / Small Business') { ?> ecp-selected <?php } ?>" data-entrepreneur="startup_or_small_business" data-value="Startup / Small Business">
                                 <h3 class="ecp-category-title"><?php _e('Startup / Small Business', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Medium Business') { ?> ecp-selected <?php } ?>" data-entrepreneur="medium_business" data-value="Medium Business">
                                 <h3 class="ecp-category-title"><?php _e('Medium Business', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Corporate') { ?> ecp-selected <?php } ?>" data-entrepreneur="corporate" data-value="Corporate">
                                 <h3 class="ecp-category-title"><?php _e('Corporate', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Other (SMB)') { ?> ecp-selected <?php } ?>" data-entrepreneur="other_smb" data-value="Other (SMB)">
                                 <h3 class="ecp-category-title"><?php _e('Other (SMB)', 'evergreen-content-poster'); ?></h3>
                              </div>
                           </div>
                           <div class="agency-option <?php if ($step5['business_type'] !== 'Agency') { ?> hidden <?php } ?> ecp-entrepreneur">
                              <!-- Agency options -->
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Freelance Marketer') { ?> ecp-selected <?php } ?>" data-entrepreneur="freelancer_marketer" data-value="Freelance Marketer">
                                 <h3 class="ecp-category-title"><?php _e('Freelance Marketer', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Marketing Agency') { ?> ecp-selected <?php } ?>" data-entrepreneur="marketing_agency" data-value="Marketing Agency">
                                 <h3 class="ecp-category-title"><?php _e('Marketing Agency', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Social Media Marketing Agency') { ?> ecp-selected <?php } ?>" data-entrepreneur="social_media_marketing_agency" data-value="Social Media Marketing Agency">
                                 <h3 class="ecp-category-title"><?php _e('Social Media Marketing Agency', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Web & Design agency') { ?> ecp-selected <?php } ?>" data-entrepreneur="web_design_agency" data-value="Web & Design agency">
                                 <h3 class="ecp-category-title"><?php _e('Web & Design agency', 'evergreen-content-poster'); ?></h3>
                              </div>
                              <div class="ecp-grid ecp-col-220 ecp-content-border <?php if ($step5['business_type_detail'] === 'Other (Agency)') { ?> ecp-selected <?php } ?>" data-entrepreneur="other_agency" data-value="Other (Agency)">
                                 <h3 class="ecp-category-title"><?php _e('Other (Agency)', 'evergreen-content-poster'); ?></h3>
                              </div>
                           </div>
                        </div>

                        <div class="ecp-clearfix"></div>

                        <!-- And finally, in what industry are you working? -->
                        <div class="industry <?php if (!$step5['business_type_detail']) { ?> hidden <?php } ?>">
                           <div class="ecp-grid ecp-col-300">
                              <p><strong><?php _e('And finally, in what industry are you working?', 'evergreen-content-poster'); ?></strong></p>
                           </div>
                           <div class="ecp-grid ecp-col-300">
                              <select name="ecp-configurator-industry" id="ecp-configurator-industry" value="" class="ecp-admin-input">
                                 <option value="Agriculture" <?php if ($step5['business_industry'] === 'Agriculture') { ?> selected <?php } ?>>&#128668; <?php _e('Agriculture', 'evergreen-content-poster'); ?></option>
                                 <option value="AI &amp; Machine" <?php if ($step5['business_industry'] === 'AI &amp; Machine') { ?> selected <?php } ?>>&#129302; <?php _e('AI &amp; Machine', 'evergreen-content-poster'); ?></option>
                                 <option value="Architecture" <?php if ($step5['business_industry'] === 'Architecture') { ?> selected <?php } ?>>&#127968; <?php _e('Architecture', 'evergreen-content-poster'); ?></option>
                                 <option value="Arts &amp; Crafts" <?php if ($step5['business_industry'] === 'Arts &amp; Crafts') { ?> selected <?php } ?>>&#129526; <?php _e('Arts &amp; Crafts', 'evergreen-content-poster'); ?></option>
                                 <option value="Automotive" <?php if ($step5['business_industry'] === 'Automotive') { ?> selected <?php } ?>>&#128663; <?php _e('Automotive', 'evergreen-content-poster'); ?></option>
                                 <option value="Beauty/Fashion" <?php if ($step5['business_industry'] === 'Beauty/Fashion') { ?> selected <?php } ?>>&#128133; <?php _e('Beauty/Fashion', 'evergreen-content-poster'); ?></option>
                                 <option value="Civil &amp; Social Organization" <?php if ($step5['business_industry'] === 'Civil &amp; Social Organization') { ?> selected <?php } ?>>&#128525; <?php _e('Civil &amp; Social Organization', 'evergreen-content-poster'); ?></option>
                                 <option value="Cleaning" <?php if ($step5['business_industry'] === 'Cleaning') { ?> selected <?php } ?>>&#129533; <?php _e('Cleaning', 'evergreen-content-poster'); ?></option>
                                 <option value="Construction" <?php if ($step5['business_industry'] === 'Construction') { ?> selected <?php } ?>>&#127959; <?php _e('Construction', 'evergreen-content-poster'); ?></option>
                                 <option value="Cryptocurrency" <?php if ($step5['business_industry'] === 'Cryptocurrency') { ?> selected <?php } ?>>&#128640; <?php _e('Cryptocurrency', 'evergreen-content-poster'); ?></option>
                                 <option value="Customer Services" <?php if ($step5['business_industry'] === 'Customer Services') { ?> selected <?php } ?>>&#128718;&#65039;<?php _e('Customer Services', 'evergreen-content-poster'); ?></option>
                                 <option value="Design" <?php if ($step5['business_industry'] === 'Design') { ?> selected <?php } ?>>&#127912; <?php _e('Design', 'evergreen-content-poster'); ?></option>
                                 <option value="Education" <?php if ($step5['business_industry'] === 'Education') { ?> selected <?php } ?>>&#127979; <?php _e('Education', 'evergreen-content-poster'); ?></option>
                                 <option value="Electronics" <?php if ($step5['business_industry'] === 'Electronics') { ?> selected <?php } ?>>&#128268; <?php _e('Electronics', 'evergreen-content-poster'); ?></option>
                                 <option value="Engineering" <?php if ($step5['business_industry'] === 'Engineering') { ?> selected <?php } ?>>&#128105;&#8205;&#128300;<?php _e('Engineering', 'evergreen-content-poster'); ?></option>
                                 <option value="Entertainment" <?php if ($step5['business_industry'] === 'Entertainment') { ?> selected <?php } ?>>&#127908; <?php _e('Entertainment', 'evergreen-content-poster'); ?></option>
                                 <option value="Entrepreneurship" <?php if ($step5['business_industry'] === 'Entrepreneurship') { ?> selected <?php } ?>>&#129489;&#127997;&#8205;&#128187;<?php _e('Entrepreneurship', 'evergreen-content-poster'); ?></option>
                                 <option value="Events Services" <?php if ($step5['business_industry'] === 'Events Services') { ?> selected <?php } ?>>&#127915; <?php _e('Events Services', 'evergreen-content-poster'); ?></option>
                                 <option value="Financial" <?php if ($step5['business_industry'] === 'Financial') { ?> selected <?php } ?>>&#129297; <?php _e('Financial', 'evergreen-content-poster'); ?></option>
                                 <option value="Fitness and sports" <?php if ($step5['business_industry'] === 'Fitness and sports') { ?> selected <?php } ?>>&#127941; <?php _e('Fitness and sports', 'evergreen-content-poster'); ?></option>
                                 <option value="Food &amp; Beverages" <?php if ($step5['business_industry'] === 'Food &amp; Beverages') { ?> selected <?php } ?>>&#127790; <?php _e('Food &amp; Beverages', 'evergreen-content-poster'); ?></option>
                                 <option value="Fund-Raising" <?php if ($step5['business_industry'] === 'Fund-Raising') { ?> selected <?php } ?>>&#128176; <?php _e('Fund-Raising', 'evergreen-content-poster'); ?></option>
                                 <option value="Gaming" <?php if ($step5['business_industry'] === 'Gaming') { ?> selected <?php } ?>>&#128377; <?php _e('Gaming', 'evergreen-content-poster'); ?></option>
                                 <option value="Health, Wellness and Fitness" <?php if ($step5['business_industry'] === 'Health, Wellness and Fitness') { ?> selected <?php } ?>>&#128134; <?php _e('Health, Wellness and Fitness', 'evergreen-content-poster'); ?></option>
                                 <option value="Hospitality" <?php if ($step5['business_industry'] === 'Hospitality') { ?> selected <?php } ?>>&#127881; <?php _e('Hospitality', 'evergreen-content-poster'); ?></option>
                                 <option value="Human Resources" <?php if ($step5['business_industry'] === 'Human Resources') { ?> selected <?php } ?>>&#129489;&#8205;&#128188; <?php _e('Human Resources', 'evergreen-content-poster'); ?></option>
                                 <option value="Insurance" <?php if ($step5['business_industry'] === 'Insurance') { ?> selected <?php } ?>>&#127808; <?php _e('Insurance', 'evergreen-content-poster'); ?></option>
                                 <option value="IT Services" <?php if ($step5['business_industry'] === 'IT Services') { ?> selected <?php } ?>>&#128190; <?php _e('IT Services', 'evergreen-content-poster'); ?></option>
                                 <option value="Law" <?php if ($step5['business_industry'] === 'Law') { ?> selected <?php } ?>>&#9878;&#65039; <?php _e('Law', 'evergreen-content-poster'); ?></option>
                                 <option value="Learning" <?php if ($step5['business_industry'] === 'Learning') { ?> selected <?php } ?>>&#129300; <?php _e('Learning', 'evergreen-content-poster'); ?></option>
                                 <option value="Manufacturing" <?php if ($step5['business_industry'] === 'Manufacturing') { ?> selected <?php } ?>>&#127981; <?php _e('Manufacturing', 'evergreen-content-poster'); ?></option>
                                 <option value="Marketing &amp; Advertising" <?php if ($step5['business_industry'] === 'Marketing &amp; Advertising') { ?> selected <?php } ?>>&#128202; <?php _e('Marketing &amp; Advertising', 'evergreen-content-poster'); ?></option>
                                 <option value="Military" <?php if ($step5['business_industry'] === 'Military') { ?> selected <?php } ?>>&#129686; <?php _e('Military', 'evergreen-content-poster'); ?></option>
                                 <option value="Music" <?php if ($step5['business_industry'] === 'Music') { ?> selected <?php } ?>>&#127929; <?php _e('Music', 'evergreen-content-poster'); ?></option>
                                 <option value="News Media" <?php if ($step5['business_industry'] === 'News Media') { ?> selected <?php } ?>>&#128240; <?php _e('News Media', 'evergreen-content-poster'); ?></option>
                                 <option value="Oil &amp; Energy" <?php if ($step5['business_industry'] === 'Oil &amp; Energy') { ?> selected <?php } ?>>&#128267; <?php _e('Oil &amp; Energy', 'evergreen-content-poster'); ?></option>
                                 <option value="Other" <?php if ($step5['business_industry'] === 'Other') { ?> selected <?php } ?>>&#10067; <?php _e('Other', 'evergreen-content-poster'); ?></option>
                                 <option value="Pharmaceutical" <?php if ($step5['business_industry'] === 'Pharmaceutical') { ?> selected <?php } ?>>&#128138; <?php _e('Pharmaceutical', 'evergreen-content-poster'); ?></option>
                                 <option value="Photography" <?php if ($step5['business_industry'] === 'Photography') { ?> selected <?php } ?>>&#128247; <?php _e('Photography', 'evergreen-content-poster'); ?></option>
                                 <option value="Political Organization" <?php if ($step5['business_industry'] === 'Political Organization') { ?> selected <?php } ?>>&#9994; <?php _e('Political Organization', 'evergreen-content-poster'); ?></option>
                                 <option value="Real Estate" <?php if ($step5['business_industry'] === 'Real Estate') { ?> selected <?php } ?>>&#129521; <?php _e('Real Estate', 'evergreen-content-poster'); ?></option>
                                 <option value="Recruiting" <?php if ($step5['business_industry'] === 'Recruiting') { ?> selected <?php } ?>>&#128188; <?php _e('Recruiting', 'evergreen-content-poster'); ?></option>
                                 <option value="Religious" <?php if ($step5['business_industry'] === 'Religious') { ?> selected <?php } ?>>&#9962; <?php _e('Religious', 'evergreen-content-poster'); ?></option>
                                 <option value="Retail" <?php if ($step5['business_industry'] === 'Retail') { ?> selected <?php } ?>>&#128717;&#65039; <?php _e('Retail', 'evergreen-content-poster'); ?></option>
                                 <option value="Sport" <?php if ($step5['business_industry'] === 'Sport') { ?> selected <?php } ?>>&#128692; <?php _e('Sport', 'evergreen-content-poster'); ?></option>
                                 <option value="Technology" <?php if ($step5['business_industry'] === 'Technology') { ?> selected <?php } ?>>&#129518; <?php _e('Technology', 'evergreen-content-poster'); ?></option>
                                 <option value="Telecommunication" <?php if ($step5['business_industry'] === 'Telecommunication') { ?> selected <?php } ?>>&#9742;&#65039; <?php _e('Telecommunication', 'evergreen-content-poster'); ?></option>
                                 <option value="Tobacco" <?php if ($step5['business_industry'] === 'Tobacco') { ?> selected <?php } ?>>&#128684; <?php _e('Tobacco', 'evergreen-content-poster'); ?></option>
                                 <option value="Transport" <?php if ($step5['business_industry'] === 'Transport') { ?> selected <?php } ?>>&#128652; <?php _e('Transport', 'evergreen-content-poster'); ?></option>
                                 <option value="Traveling" <?php if ($step5['business_industry'] === 'Traveling') { ?> selected <?php } ?>>&#129523; <?php _e('Traveling', 'evergreen-content-poster'); ?></option>
                                 <option value="Veterinary" <?php if ($step5['business_industry'] === 'Veterinary') { ?> selected <?php } ?>>&#128054; <?php _e('Veterinary', 'evergreen-content-poster'); ?></option>
                                 <option value="Writing &amp; Editing" <?php if ($step5['business_industry'] === 'Writing &amp; Editing') { ?> selected <?php } ?>>&#128211; <?php _e('Writing &amp; Editing', 'evergreen-content-poster'); ?></option>
                              </select>
                           </div>
                        </div>

                        <div class="ecp-clearfix"></div>

                        <div class="ecp-grid-right">
                           <a href="#" class="button ecp-green-button ecp-next" data-step="5" style="color:#1b3a51; font-weight: 600;"><?php _e('next', 'evergreen-content-poster'); ?></a>
                        </div>
                        <div class="ecp-grid">
                           <a href="#" class="button ecp-grey-button ecp-previous" data-step="5" style="font-weight: 600;"><?php _e('previous', 'evergreen-content-poster'); ?></a>
                        </div>

                     </div> <!-- end step 5 -->

                     <!-- step 6 -->
                     <div id="step-6" class="step-content">
                        <?php
                        $current_user = wp_get_current_user();
                        $user_email = ($current_user->ID > 0) ? $current_user->user_email : ''; ?>
                        <h2 style="text-align: center;"><?php _e('Optional step 6: Subscribe to our newsletter', 'evergreen-content-poster'); ?></h2>
                        <p><?php _e('Sign up for our newsletter if you would like to keep up-to-date about the Evergreen Content Poster, and interesting news and tips from the world of growing your business.', 'evergreen-content-poster'); ?></p>
                        <form id="ecp-onboarding-newsletter-form" method="post" action="">
                           <div class="ecp-grid ecp-col-220">
                              <label for="ecp-newsletter-subcribe">
                                 <p class="ecp-input-label" style="font-size: 13px; margin-top: 20px;"><?php _e('Your best email address', 'evergreen-content-poster'); ?></p>
                              </label>
                           </div>
                           <div class="ecp-grid ecp-col-380">
                              <input id="ecp-newsletter-subcribe" class="ecp-admin-input" type="email" name="ecp-newsletter-email" autocomplete="email" value="<?php echo $user_email; ?>">
                              <div class="email-error hidden email-noti"><?php _e('Email address is not valid', 'evergreen-content-poster') ?></div>
                              <div class="email-success hidden email-noti"><?php _e('Almost finished... We need to confirm your email address. To complete the subscription process, please click the link in the email we just sent you.', 'evergreen-content-poster') ?></div>
                           </div>
                           <div class="ecp-grid ecp-col-220">
                              <button id="settings_subscribe" class="button ecp-configurator-signup ecp-red-button" style="margin-top: 0; height: 50px;"><?php _e('sign me up!', 'evergreen-content-poster'); ?></button>
                           </div>
                        </form>
                        <div class="ecp-grid ecp-col-940">
                           <p class="ecp-configurator-confirmation-message" style="display: none;"><?php _e('Almost finished... We need to confirm your email address. To complete the subscription process, please click the link in the email we just sent you.', 'evergreen-content-poster'); ?></p>
                        </div>
                        <div class="ecp-grid ecp-col-940">
                           <p><em><?php echo sprintf(
                                       /* translators: %1$s is a link start tag our Privacy Policy, %2$s is the link closing tag */
                                       esc_html__('We respect your privacy. Read our %1sprivacy policy%2s on how we handle your personal information.', 'evergreen-content-poster'),
                                       '<a href="https://www.evergreencontentposter.com/privacy-policy/?utm_source=plugin%20configurator&utm_medium=software&utm_campaign=evergreen%20content%20poster" target="_blank">',
                                       '</a>'
                                    ); ?></em></p>
                        </div>
                        <div class="ecp-grid-right">
                           <a href="#" class="button ecp-green-button ecp-next" data-step="6" style="color:#1b3a51; font-weight: 600;"><?php _e('next', 'evergreen-content-poster'); ?></a>
                        </div>
                        <div class="ecp-grid">
                           <a href="#" class="button ecp-grey-button ecp-previous" data-step="6" style="font-weight: 600;"><?php _e('previous', 'evergreen-content-poster'); ?></a>
                        </div>
                        <script src="//cdnjs.cloudflare.com/ajax/libs/validate.js/0.13.1/validate.min.js"></script>
                     </div> <!-- end step 6 -->

                     <!-- step 7 -->
                     <div id="step-7" class="step-content">
                        <h2 style="text-align: center;"><?php _e('That\'s it you made it through the onboarding!', 'evergreen-content-poster'); ?></h2>
                        <div class="ecp-grid ecp-col-380">
                           <img src="<?php echo EVERGREEN_CONTENT_POSTER_PATH; ?>/admin/img/ecp-onboarding-step-7.svg" width="180" height="153" style="display: block; margin: 3em auto;">
                        </div>
                        <div class="ecp-grid ecp-col-460">
                           <p><?php _e('Woohoo! You\'re ready to start sharing your evergreen content via social media.', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('Now don\'t forget to go through your back catalogue to create social media posts for all your evergreen content, or maybe create a library of posts for your YouTube videos or inspirational quotes for your followers.', 'evergreen-content-poster'); ?></p>
                           <p><?php _e('The possibilities are almost endless.', 'evergreen-content-poster'); ?></p>
                        </div>
                        <div class="ecp-grid ecp-col-860">
                           <h3 style="text-align: center;"><?php _e('Do you still feel stuck and want a personal demo?', 'evergreen-content-poster'); ?></h3>
                           <p><?php _e('We\'ll talk more about how this plugin can help you grow your traffic via social media, answer any questions you may have, help you get unstuck or maybe you just want to have a small chat?', 'evergreen-content-poster'); ?></p>
                           <iframe src="https://meetings.hansvangent.com?view=compact" style="width:100%; height:650px;" frameborder="0" scrolling="yes"></iframe>
                        </div>

                        <div class="ecp-grid-right ecp-col-120">
                           <a href="<?php echo $dashboard_url; ?>" class="button ecp-green-button ecp-onboard-finish" data-step="7" style="color:#1b3a51; font-weight: 600;"><?php _e('close', 'evergreen-content-poster'); ?></a>
                        </div>
                        <div class="ecp-grid">
                           <a href="#" class="button ecp-grey-button ecp-previous" data-step="7" style="font-weight: 600;"><?php _e('previous', 'evergreen-content-poster'); ?></a>
                        </div>

                     </div> <!-- end step 7 -->

                  </div>
               </div>
            </div>
         </div>
      </div>

      <div id="delete-schedule" class="modal all-modal">
         <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Are you sure you want to delete this timeslot?', 'evergreen-content-poster'); ?></p>
         <a id="ecp-delete-schedule-modal" href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-remove-schedule-action jquery-modal-close"><?php _e('Ok', 'evergreen-content-poster'); ?></a>
         <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close"><?php _e('Cancel', 'evergreen-content-poster'); ?></a>
      </div>
      <div id="confirm-custom-schedule-modal" class="modal all-modal">
         <p style="border-bottom: 1px solid #a4a4a4; padding: 20px 0"><?php _e('Do you want to use your current schedule as a basis to build your own schedule?', 'evergreen-content-poster'); ?></p>
         <a href="#" style="padding: 10px 30px;" class="button ecp-navy-button ecp-button jquery-modal-close ecp-schedule-custom-select-yes"><?php _e('Yes', 'evergreen-content-poster'); ?></a>
         <a href="#" style="color:#000; text-decoration:none;margin-right:20px;padding: 10px 30px;border: 1px solid #1b3a51;float: right" class="ecp-button jquery-modal-close ecp-schedule-custom-select-no"><?php _e('No', 'evergreen-content-poster'); ?></a>
      </div>

<?php
   }
}
