<?php
/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @link       https://www.evergreencontentposter.com/
 * @since      1.0.0
 * @package    Evergreen_Content_Poster
 * @subpackage Evergreen_Content_Poster/Activator
 * @author     evergreencontentposter <support@evergreencontentposter.com>
 */
class Evergreen_Content_Poster_Activator
{
    /**
     * Runs the installation and update routines when the plugin is activated.
     *
     * @since   1.0.0
     *
     * @param   bool    $network_wide   Is network wide activation
     */

    public static function ecp_activate($network_wide): void
    {
        $current_user = wp_get_current_user();
        if (! current_user_can('activate_plugins')) {
            return;
        }

        $general_settings = get_option('ecp_general_settings');
        if (isset($general_settings['ecp_posting_schedule'])) {
            if ($general_settings['ecp_posting_schedule'] === 'timestamp') {
                $ecp_schedule_option = 3;
            } elseif ($general_settings['ecp_posting_schedule'] === 'empty_queue') {
                $ecp_schedule_option = 2;
            } else {
                $ecp_schedule_option = 1;
            }
        } else {
            $ecp_schedule_option = 0;
        }

        // update statistic api
        $token = evergreenGetStatisticsToken();
        $number_active_plugins = 0;
        if (get_option('active_plugins')) {
            $number_active_plugins = count(get_option('active_plugins'));
        }

        //get lang
        $common = new Evergreen_Content_Poster_Common();
        $lang = $common->ecp_get_user_locale();
        $data['sites'] = [
            'url' => home_url(),
            'token' => $token,
            'activation_date' => date('Y-m-d H:i:s'),
            'status' => 'activated',
            'version' => EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION,
            'contact_email' => $current_user->user_email ? $current_user->user_email : '',
            'plugin_name' => 'evergreen content poster',
            'ecp_schedule_option' => $ecp_schedule_option,
            'number_active_plugins' => $number_active_plugins,
        ];

        if ($lang) {
            $data['sites']['lang'] = $lang;
        }

        updateApiStatistics($data);

        // Initialise Plugin
        $ecp = Evergreen_Content_Poster::get_instance();

        // Check if we are on a multisite install, activating network wide, or a single install
        if (! is_multisite() || ! $network_wide) {
            // Single Site activation
            // $ecp->get_class( 'install' )->install();
            $ecp->install();
        } else {
            // Multisite network wide activation
            //	        $sites = get_sites( array(
            //	            'number' => 0,
            //	        ) );
            //	        foreach ( $sites as $site ) {
            //	            switch_to_blog( $site->blog_id );
            //	            $ecp = (new Evergreen_Content_Poster())->install();
            //	            restore_current_blog();
            //	        }

            foreach (get_sites(['fields' => 'ids']) as $blog_id) {
                switch_to_blog($blog_id);
                $ecp->install();
                restore_current_blog();
            }
        }
    }

    /**
     * Runs the installation and update routines when the plugin is activated
     * on a WPMU site.
     *
     * @since   1.0.0
     *
     * @param   int     $blog_id    Site ID
     */
    public function ecp_activate_new_site($blog_id): void
    {
        // Initialise Plugin
        $ecp = Evergreen_Content_Poster::get_instance();

        // Run installation routine
        switch_to_blog($blog_id);
        $ecp = Evergreen_Content_Poster::install();
        restore_current_blog();
    }

    /**
     * The code that prepares and pre-registers the plugin settings/options
     */
    public static function register_settings(): void
    {
        //Declare all options and if applicable, the default information
        $opts = [
            'ecp_version' => EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION,
            'ecp_db_version' => EVERGREEN_CONTENT_POSTER_DB_VERSION,
            'premium' => 0,
        ];
        $timezone = get_option('timezone_string');

        add_option(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_options', $opts);
        add_option(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_buffer_token', 'null');
        add_option(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_buffer_profiles', 'null');
        add_option(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_general_settings', []);
        add_option(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_schedule_settings', []);
        add_option(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_timezone', !empty($timezone) ? $timezone : 'UTC+0');

        //Register these settings with the plugin
        register_setting(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_setting_opts', EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_options');
        register_setting(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_setting_token', EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_buffer_token');
        register_setting(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_setting_profiles', EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_buffer_profiles');
        register_setting(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_setting_general', EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_general_settings');
        register_setting(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_setting_schedules', EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_schedule_settings');
        register_setting(EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_setting_timezone', EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_timezone');

        // @note: we are not using the Settings API properly. Update in the future.
        // this does not work, as settings API is meant to store ALL plugin setting under 1 option name
        // $setting_options = [
        //     EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_options',
        //     EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_buffer_token',
        //     EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_buffer_profiles',
        // ];
        // register_setting( EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_plugin_settings', $setting_options);
    }
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-evergreen_content_poster-activator.php
 */
function activate_evergreen_content_poster($network_wide): void
{
    global $wpdb;
    Evergreen_Content_Poster_Activator::ecp_activate($network_wide);

    add_action('wpmu_new_blog', 'ecp_activate_new_site');
    add_action('activate_blog', 'ecp_activate_new_site');

    // activate plugin setting options
    if (! is_multisite() || ! $network_wide) {
        // Single Site activation
        // $ecp->get_class( 'install' )->install();
        Evergreen_Content_Poster_Activator::register_settings();
    } else {
        // Multisite network wide activation
        Evergreen_Content_Poster_Activator::register_settings();
        foreach (get_sites(['fields' => 'ids']) as $blog_id) {
            switch_to_blog($blog_id);
            Evergreen_Content_Poster_Activator::register_settings();
            restore_current_blog();
        }
    }

    // Don't do redirects when multiple plugins are bulk activated
    if (
        (isset($_REQUEST['action']) && 'activate-selected' === sanitize_text_field($_REQUEST['action'])) &&
        (isset($_POST['checked']) && count($_POST['checked']) > 1)
    ) {
        return;
    }

    $e = new Evergreen_Content_Poster_Cron_Scheduler();
    if (! is_multisite() || ! $network_wide) {
        // Single Site activation
        $today_now = date('Y-m-d H:i:s');
        $date_last_active = get_option('ecp_date_last_active');
        if (isset($date_last_active) && !is_null($date_last_active)) {
            // update option ecp_date_last_active with current time
            update_option('ecp_date_last_active', $today_now);
        } else {
            // add new option
            add_option('ecp_date_last_active', $today_now);
        }
        // Call the cron schedule
        $e->schedule_cron_event('timestamp');
    } else {
        // Multisite network wide activation
        foreach (get_sites(['fields' => 'ids']) as $blog_id) {
            switch_to_blog($blog_id);
            $today_now = date('Y-m-d H:i:s');
            $date_last_active = get_option('ecp_date_last_active');
            if (isset($date_last_active) && !is_null($date_last_active)) {
                // update option ecp_date_last_active with current time
                update_option('ecp_date_last_active', $today_now);
            } else {
                // add new option
                add_option('ecp_date_last_active', $today_now);
            }
            // Call the cron schedule
            $e->schedule_cron_event('timestamp');
            restore_current_blog();
        }
    }

    // needed as validator when redirecting user after activating the plugin
    add_option('ecp_plugin_activation_redirect', wp_get_current_user()->ID);
    // ecp_plugin_settings_redirect();
}

/**
 * Redirect the user directly to the settings page one plugin is activated.
 *
 * @return void
 */
function ecp_plugin_settings_redirect(): void
{
    // Make sure it's the correct user
    if (intval(get_option('ecp_plugin_activation_redirect', false)) === wp_get_current_user()->ID && wp_get_current_user()->ID > 0) {
        // Make sure we don't redirect again after this one
        delete_option('ecp_plugin_activation_redirect');
        wp_safe_redirect(admin_url('/admin.php?page=evergreen-content-configurator'));
    }
}
