<?php
/**
 * The core Common class.
 *
 * This class is used for handling all Common related functions.
 *
 * @link       https://www.evergreencontentposter.com/
 * @since      1.0.0
 * @package    Evergreen_Content_Poster
 * @subpackage Evergreen_Content_Poster/includes
 * @author     evergreencontentposter <support@evergreencontentposter.com>
 */

class Evergreen_Content_Poster_Common
{
    private $option_general_settings = EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_general_settings';
    private $option_schedule_settings = EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_schedule_settings';
    private $option_timezone = EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_timezone';

    /**
     * Get general setting from wp_options
     *
     * @return array|mixed|void
     */
    public function general_settings()
    {
        $settings = get_option($this->option_general_settings);

        // "false" if token does not exist (plugin is deauthorized)
        // "null" if plugin is activated first time but no connection has been made yet to Buffer
        if (!$settings || empty($settings)) {
            $settings = [
                'eg_timezone' => $this->wp_timezone(),
                'eg_position' => 'top',
                'eg_postingorder' => 'random',
                'eg_numberofdays' => 1,
                'utm_tags' => 'N',
				'notification_emails' => '',
				'publish_notification' => 'N',
				'publish_failure' => 'N',
            ];
        }

        if (!isset($settings['ecp_posting_schedule'])) {
            $settings['ecp_posting_schedule'] = 'daily_posts';
        }
        return $settings;
    }

    /**
     * Save general setting to wp_options
     *
     * @param $settings
     * @return bool
     */
    public function save_settings($settings)
    {
        if (! current_user_can('manage_options')) {
            return false;
        }

        if (empty($settings)) {
            return false;
        }

        return update_option($this->option_general_settings, $settings);
    }

    /**
     * Save settings during onboarding
     *
     * @param $settings
     * @return bool
     */
    public function save_settings_config($settings)
    {
        if (! current_user_can('manage_options')) {
            return false;
        }

        if (empty($settings)) {
            return false;
        }

        $general_settings = get_option($this->option_general_settings);

        foreach ($settings as $key => $value) {
            $general_settings[$key] = $value;
        }

        return update_option($this->option_general_settings, $general_settings);
    }

    /**
     * Get schedules from wp_options
     *
     * @return array|mixed|void
     */
    public function schedules()
    {
        $settings = get_option($this->option_schedule_settings);

        // "false" if token does not exist (plugin is deauthorized)
        // "null" if plugin is activated first time but no connection has been made yet to Buffer
        if (!$settings || empty($settings)) {
            return [
                'schedules' => [],
                'generals' => [],
            ];
        }
        return $settings;
    }

    /**
     * Get Buffer plugin timezone. Else, return default WP timezone.
     * @since      1.0.0
     */
    public function timezone()
    {
        $timezone = $this->load_timezone();

        // "false" if token does not exist (plugin is deauthorized)
        // "null" if plugin is activated first time but no connection has been made yet to Buffer
        if (!$timezone || 'null' === $timezone) {
            $timezone = $this->wp_timezone();
        }
        return $timezone;
    }

    /**
     * Get the current timezone set in WordPress.
     *
     * * @since      1.0.0
     */
    public function load_timezone()
    {
        return get_option($this->option_timezone);
    }

    public function wp_timezone()
    {
        $current_offset = get_option('gmt_offset');
        $tzstring = get_option('timezone_string');

        $check_zone_info = true;

        // Remove old Etc mappings. Fallback to gmt_offset.
        if (false !== strpos($tzstring, 'Etc/GMT')) {
            $tzstring = '';
        }

        if (empty($tzstring)) { // Create a UTC+- zone if no timezone string exists.
            $check_zone_info = false;
            if (0 === $current_offset) {
                $tzstring = 'UTC+0';
            } elseif ($current_offset < 0) {
                $tzstring = 'UTC' . $current_offset;
            } else {
                $tzstring = 'UTC+' . $current_offset;
            }
        }

        return $tzstring;
    }

    /**
     * List of available locales.
     *
     * @var array Multidimensional Array of available locals.
     */
    private $ecp_locales = [
		'af' => [
			'slug' => 'af',
			'name' => 'Afrikaans',
		],
		'ak' => [
			'slug' => 'ak',
			'name' => 'Akan',
		],
		'am' => [
			'slug' => 'am',
			'name' => 'Amharic',
		],
		'ar' => [
			'slug' => 'ar',
			'name' => 'Arabic',
		],
		'arq' => [
			'slug' => 'arq',
			'name' => 'Algerian Arabic',
		],
		'ary' => [
			'slug' => 'ary',
			'name' => 'Moroccan Arabic',
		],
		'as' => [
			'slug' => 'as',
			'name' => 'Assamese',
		],
		'ast' => [
			'slug' => 'ast',
			'name' => 'Asturian',
		],
		'az' => [
			'slug' => 'az',
			'name' => 'Azerbaijani',
		],
		'azb' => [
			'slug' => 'azb',
			'name' => 'South Azerbaijani',
		],
		'az_TR' => [
			'slug' => 'az-tr',
			'name' => 'Azerbaijani (Turkey)',
		],
		'ba' => [
			'slug' => 'ba',
			'name' => 'Bashkir',
		],
		'bal' => [
			'slug' => 'bal',
			'name' => 'Catalan (Balear)',
		],
		'bcc' => [
			'slug' => 'bcc',
			'name' => 'Balochi Southern',
		],
		'bel' => [
			'slug' => 'bel',
			'name' => 'Belarusian',
		],
		'bg_BG' => [
			'slug' => 'bg',
			'name' => 'Bulgarian',
		],
		'bn_BD' => [
			'slug' => 'bn',
			'name' => 'Bengali',
		],
		'bo' => [
			'slug' => 'bo',
			'name' => 'Tibetan',
		],
		'bre' => [
			'slug' => 'br',
			'name' => 'Breton',
		],
		'bs_BA' => [
			'slug' => 'bs',
			'name' => 'Bosnian',
		],
		'ca' => [
			'slug' => 'ca',
			'name' => 'Catalan',
		],
		'ceb' => [
			'slug' => 'ceb',
			'name' => 'Cebuano',
		],
		'ckb' => [
			'slug' => 'ckb',
			'name' => 'Kurdish (Sorani)',
		],
		'co' => [
			'slug' => 'co',
			'name' => 'Corsican',
		],
		'cs_CZ' => [
			'slug' => 'cs',
			'name' => 'Czech',
		],
		'cy' => [
			'slug' => 'cy',
			'name' => 'Welsh',
		],
		'da_DK' => [
			'slug' => 'da',
			'name' => 'Danish',
		],
		'de_DE' => [
			'slug' => 'de',
			'name' => 'German',
		],
		'de_CH' => [
			'slug' => 'de-ch',
			'name' => 'German (Switzerland)',
		],
		'dv' => [
			'slug' => 'dv',
			'name' => 'Dhivehi',
		],
		'dzo' => [
			'slug' => 'dzo',
			'name' => 'Dzongkha',
		],
		'el' => [
			'slug' => 'el',
			'name' => 'Greek',
		],
		'art_xemoji' => [
			'slug' => 'art-xemoji',
			'name' => 'Emoji',
		],
		'en_US' => [
			'slug' => 'en',
			'name' => 'English',
		],
		'en_AU' => [
			'slug' => 'en-au',
			'name' => 'English (Australia)',
		],
		'en_CA' => [
			'slug' => 'en-ca',
			'name' => 'English (Canada)',
		],
		'en_GB' => [
			'slug' => 'en-gb',
			'name' => 'English (UK)',
		],
		'en_NZ' => [
			'slug' => 'en-nz',
			'name' => 'English (New Zealand)',
		],
		'en_ZA' => [
			'slug' => 'en-za',
			'name' => 'English (South Africa)',
		],
		'eo' => [
			'slug' => 'eo',
			'name' => 'Esperanto',
		],
		'es_ES' => [
			'slug' => 'es',
			'name' => 'Spanish (Spain)',
		],
		'es_AR' => [
			'slug' => 'es-ar',
			'name' => 'Spanish (Argentina)',
		],
		'es_CL' => [
			'slug' => 'es-cl',
			'name' => 'Spanish (Chile)',
		],
		'es_CO' => [
			'slug' => 'es-co',
			'name' => 'Spanish (Colombia)',
		],
		'es_CR' => [
			'slug' => 'es-cr',
			'name' => 'Spanish (Costa Rica)',
		],
		'es_GT' => [
			'slug' => 'es-gt',
			'name' => 'Spanish (Guatemala)',
		],
		'es_MX' => [
			'slug' => 'es-mx',
			'name' => 'Spanish (Mexico)',
		],
		'es_PE' => [
			'slug' => 'es-pe',
			'name' => 'Spanish (Peru)',
		],
		'es_PR' => [
			'slug' => 'es-pr',
			'name' => 'Spanish (Puerto Rico)',
		],
		'es_VE' => [
			'slug' => 'es-ve',
			'name' => 'Spanish (Venezuela)',
		],
		'et' => [
			'slug' => 'et',
			'name' => 'Estonian',
		],
		'eu' => [
			'slug' => 'eu',
			'name' => 'Basque',
		],
		'fa_IR' => [
			'slug' => 'fa',
			'name' => 'Persian',
		],
		'fa_AF' => [
			'slug' => 'fa-af',
			'name' => 'Persian (Afghanistan)',
		],
		'fuc' => [
			'slug' => 'fuc',
			'name' => 'Fulah',
		],
		'fi' => [
			'slug' => 'fi',
			'name' => 'Finnish',
		],
		'fo' => [
			'slug' => 'fo',
			'name' => 'Faroese',
		],
		'fr_FR' => [
			'slug' => 'fr',
			'name' => 'French (France)',
		],
		'fr_BE' => [
			'slug' => 'fr-be',
			'name' => 'French (Belgium)',
		],
		'fr_CA' => [
			'slug' => 'fr-ca',
			'name' => 'French (Canada)',
		],
		'frp' => [
			'slug' => 'frp',
			'name' => 'Arpitan',
		],
		'fur' => [
			'slug' => 'fur',
			'name' => 'Friulian',
		],
		'fy' => [
			'slug' => 'fy',
			'name' => 'Frisian',
		],
		'ga' => [
			'slug' => 'ga',
			'name' => 'Irish',
		],
		'gd' => [
			'slug' => 'gd',
			'name' => 'Scottish Gaelic',
		],
		'gl_ES' => [
			'slug' => 'gl',
			'name' => 'Galician',
		],
		'gn' => [
			'slug' => 'gn',
			'name' => 'Guarani',
		],
		'gsw' => [
			'slug' => 'gsw',
			'name' => 'Swiss German',
		],
		'gu' => [
			'slug' => 'gu',
			'name' => 'Gujarati',
		],
		'hat' => [
			'slug' => 'hat',
			'name' => 'Haitian Creole',
		],
		'hau' => [
			'slug' => 'hau',
			'name' => 'Hausa',
		],
		'haw_US' => [
			'slug' => 'haw',
			'name' => 'Hawaiian',
		],
		'haz' => [
			'slug' => 'haz',
			'name' => 'Hazaragi',
		],
		'he_IL' => [
			'slug' => 'he',
			'name' => 'Hebrew',
		],
		'hi_IN' => [
			'slug' => 'hi',
			'name' => 'Hindi',
		],
		'hr' => [
			'slug' => 'hr',
			'name' => 'Croatian',
		],
		'hu_HU' => [
			'slug' => 'hu',
			'name' => 'Hungarian',
		],
		'hy' => [
			'slug' => 'hy',
			'name' => 'Armenian',
		],
		'id_ID' => [
			'slug' => 'id',
			'name' => 'Indonesian',
		],
		'ido' => [
			'slug' => 'ido',
			'name' => 'Ido',
		],
		'is_IS' => [
			'slug' => 'is',
			'name' => 'Icelandic',
		],
		'it_IT' => [
			'slug' => 'it',
			'name' => 'Italian',
		],
		'ja' => [
			'slug' => 'ja',
			'name' => 'Japanese',
		],
		'jv_ID' => [
			'slug' => 'jv',
			'name' => 'Javanese',
		],
		'ka_GE' => [
			'slug' => 'ka',
			'name' => 'Georgian',
		],
		'kab' => [
			'slug' => 'kab',
			'name' => 'Kabyle',
		],
		'kal' => [
			'slug' => 'kal',
			'name' => 'Greenlandic',
		],
		'kin' => [
			'slug' => 'kin',
			'name' => 'Kinyarwanda',
		],
		'kk' => [
			'slug' => 'kk',
			'name' => 'Kazakh',
		],
		'km' => [
			'slug' => 'km',
			'name' => 'Khmer',
		],
		'kn' => [
			'slug' => 'kn',
			'name' => 'Kannada',
		],
		'ko_KR' => [
			'slug' => 'ko',
			'name' => 'Korean',
		],
		'kir' => [
			'slug' => 'kir',
			'name' => 'Kyrgyz',
		],
		'lb_LU' => [
			'slug' => 'lb',
			'name' => 'Luxembourgish',
		],
		'li' => [
			'slug' => 'li',
			'name' => 'Limburgish',
		],
		'lin' => [
			'slug' => 'lin',
			'name' => 'Lingala',
		],
		'lo' => [
			'slug' => 'lo',
			'name' => 'Lao',
		],
		'lt_LT' => [
			'slug' => 'lt',
			'name' => 'Lithuanian',
		],
		'lv' => [
			'slug' => 'lv',
			'name' => 'Latvian',
		],
		'me_ME' => [
			'slug' => 'me',
			'name' => 'Montenegrin',
		],
		'mg_MG' => [
			'slug' => 'mg',
			'name' => 'Malagasy',
		],
		'mk_MK' => [
			'slug' => 'mk',
			'name' => 'Macedonian',
		],
		'ml_IN' => [
			'slug' => 'ml',
			'name' => 'Malayalam',
		],
		'mlt' => [
			'slug' => 'mlt',
			'name' => 'Maltese',
		],
		'mn' => [
			'slug' => 'mn',
			'name' => 'Mongolian',
		],
		'mr' => [
			'slug' => 'mr',
			'name' => 'Marathi',
		],
		'mri' => [
			'slug' => 'mri',
			'name' => 'Maori',
		],
		'ms_MY' => [
			'slug' => 'ms',
			'name' => 'Malay',
		],
		'my_MM' => [
			'slug' => 'mya',
			'name' => 'Myanmar (Burmese)',
		],
		'ne_NP' => [
			'slug' => 'ne',
			'name' => 'Nepali',
		],
		'nb_NO' => [
			'slug' => 'nb',
			'name' => 'Norwegian (Bokmal)',
		],
		'nl_NL' => [
			'slug' => 'nl',
			'name' => 'Dutch',
		],
		'nl_BE' => [
			'slug' => 'nl-be',
			'name' => 'Dutch (Belgium)',
		],
		'nn_NO' => [
			'slug' => 'nn',
			'name' => 'Norwegian (Nynorsk)',
		],
		'oci' => [
			'slug' => 'oci',
			'name' => 'Occitan',
		],
		'ory' => [
			'slug' => 'ory',
			'name' => 'Oriya',
		],
		'os' => [
			'slug' => 'os',
			'name' => 'Ossetic',
		],
		'pa_IN' => [
			'slug' => 'pa',
			'name' => 'Punjabi',
		],
		'pl_PL' => [
			'slug' => 'pl',
			'name' => 'Polish',
		],
		'pt_BR' => [
			'slug' => 'pt-br',
			'name' => 'Portuguese (Brazil)',
		],
		'pt_PT' => [
			'slug' => 'pt',
			'name' => 'Portuguese (Portugal)',
		],
		'ps' => [
			'slug' => 'ps',
			'name' => 'Pashto',
		],
		'rhg' => [
			'slug' => 'rhg',
			'name' => 'Rohingya',
		],
		'ro_RO' => [
			'slug' => 'ro',
			'name' => 'Romanian',
		],
		'roh' => [
			'slug' => 'roh',
			'name' => 'Romansh',
		],
		'ru_RU' => [
			'slug' => 'ru',
			'name' => 'Russian',
		],
		'rue' => [
			'slug' => 'rue',
			'name' => 'Rusyn',
		],
		'rup_MK' => [
			'slug' => 'rup',
			'name' => 'Aromanian',
		],
		'sah' => [
			'slug' => 'sah',
			'name' => 'Sakha',
		],
		'sa_IN' => [
			'slug' => 'sa-in',
			'name' => 'Sanskrit',
		],
		'scn' => [
			'slug' => 'scn',
			'name' => 'Sicilian',
		],
		'si_LK' => [
			'slug' => 'si',
			'name' => 'Sinhala',
		],
		'sk_SK' => [
			'slug' => 'sk',
			'name' => 'Slovak',
		],
		'sl_SI' => [
			'slug' => 'sl',
			'name' => 'Slovenian',
		],
		'sna' => [
			'slug' => 'sna',
			'name' => 'Shona',
		],
		'snd' => [
			'slug' => 'snd',
			'name' => 'Sindhi',
		],
		'so_SO' => [
			'slug' => 'so',
			'name' => 'Somali',
		],
		'sq' => [
			'slug' => 'sq',
			'name' => 'Albanian',
		],
		'sq_XK' => [
			'slug' => 'sq-xk',
			'name' => 'Shqip (Kosovo)',
		],
		'sr_RS' => [
			'slug' => 'sr',
			'name' => 'Serbian',
		],
		'srd' => [
			'slug' => 'srd',
			'name' => 'Sardinian',
		],
		'su_ID' => [
			'slug' => 'su',
			'name' => 'Sundanese',
		],
		'sv_SE' => [
			'slug' => 'sv',
			'name' => 'Swedish',
		],
		'sw' => [
			'slug' => 'sw',
			'name' => 'Swahili',
		],
		'syr' => [
			'slug' => 'syr',
			'name' => 'Syriac',
		],
		'szl' => [
			'slug' => 'szl',
			'name' => 'Silesian',
		],
		'ta_IN' => [
			'slug' => 'ta',
			'name' => 'Tamil',
		],
		'ta_LK' => [
			'slug' => 'ta-lk',
			'name' => 'Tamil (Sri Lanka)',
		],
		'tah' => [
			'slug' => 'tah',
			'name' => 'Tahitian',
		],
		'te' => [
			'slug' => 'te',
			'name' => 'Telugu',
		],
		'tg' => [
			'slug' => 'tg',
			'name' => 'Tajik',
		],
		'th' => [
			'slug' => 'th',
			'name' => 'Thai',
		],
		'tir' => [
			'slug' => 'tir',
			'name' => 'Tigrinya',
		],
		'tl' => [
			'slug' => 'tl',
			'name' => 'Tagalog',
		],
		'tr_TR' => [
			'slug' => 'tr',
			'name' => 'Turkish',
		],
		'tt_RU' => [
			'slug' => 'tt',
			'name' => 'Tatar',
		],
		'tuk' => [
			'slug' => 'tuk',
			'name' => 'Turkmen',
		],
		'twd' => [
			'slug' => 'twd',
			'name' => 'Tweants',
		],
		'tzm' => [
			'slug' => 'tzm',
			'name' => 'Tamazight (Central Atlas)',
		],
		'ug_CN' => [
			'slug' => 'ug',
			'name' => 'Uighur',
		],
		'uk' => [
			'slug' => 'uk',
			'name' => 'Ukrainian',
		],
		'ur' => [
			'slug' => 'ur',
			'name' => 'Urdu',
		],
		'uz_UZ' => [
			'slug' => 'uz',
			'name' => 'Uzbek',
		],
		'vi' => [
			'slug' => 'vi',
			'name' => 'Vietnamese',
		],
		'wa' => [
			'slug' => 'wa',
			'name' => 'Walloon',
		],
		'xho' => [
			'slug' => 'xho',
			'name' => 'Xhosa',
		],
		'xmf' => [
			'slug' => 'xmf',
			'name' => 'Mingrelian',
		],
		'yor' => [
			'slug' => 'yor',
			'name' => 'Yoruba',
		],
		'zh_CN' => [
			'slug' => 'zh-cn',
			'name' => 'Chinese (China)',
		],
		'zh_HK' => [
			'slug' => 'zh-hk',
			'name' => 'Chinese (Hong Kong)',
		],
		'zh_TW' => [
			'slug' => 'zh-tw',
			'name' => 'Chinese (Taiwan)',
		],
		'de_DE_formal' => [
			'slug' => 'de/formal',
			'name' => 'German (Formal)',
		],
		'nl_NL_formal' => [
			'slug' => 'nl/formal',
			'name' => 'Dutch (Formal)',
		],
		'de_CH_informal' => [
			'slug' => 'de-ch/informal',
			'name' => 'Chinese (Taiwan)',
		],
		'pt_PT_ao90' => [
			'slug' => 'pt/ao90',
			'name' => 'Portuguese (Portugal, AO90)',
		],
	];

    /**
     * List of translated locales.
     *
     * @var array Associative Array of available translated locals.
     */
    private $ecp_translated_locales = [
        'en',
	    'nl',
		'nl-be',
		'de',
		'es',
	];

    /**
     * Get the user's locale.
     */
    public function ecp_get_user_locale()
    {
        global $wp_version;
        if (version_compare($wp_version, '4.7.0', '>=')) {
            return get_user_locale();
        }
        $user = wp_get_current_user();
        if ($user) {
            $locale = $user->locale;
        }

        return $locale ? $locale : get_locale();
    }

    /**
     * @return array
     */
    public function getLocales()
    {
        return $this->ecp_locales;
    }

    /**
     * @return array
     */
    public function getEcpTranslatedLocales()
    {
        return $this->ecp_translated_locales;
    }
}
