<?php
/**
 * Runs any steps related to the cron activities.
 *
 * @link       https://www.evergreencontentposter.com/
 * @since      1.0.0
 * @package    Evergreen_Content_poster
 * @subpackage Evergreen_Content_Poster/includes
 * @author     evergreencontentposter <support@evergreencontentposter.com>
 */
class Evergreen_Content_Poster_Cron_Scheduler
{
    /**
     * Holds the base class object.
     *
     * @since   1.0.0
     *
     * @var     object
     */
    public $base;

    /**
     * Constructor
     *
     * @param object $base Base Plugin Class
     * @since   1.0.0
     */
    public function __construct()
    {
        add_filter('cron_schedules', [$this, 'schedule_add_cron_interval'], 0);
    }

    public function schedule_add_cron_interval($schedules)
    {
        $schedules['one_minute'] = [
			'interval' => 60,
			'display' => esc_html__('Every One Minute'),
        ];
        $schedules['twice_hourly'] = [
			'interval' => 1800,
			'display' => esc_html__('Every 30 Minutes'),
		];
        $general_settings = get_option('ecp_general_settings');

        foreach ($general_settings as $key => $value) {
            if (stripos($key, 'post_per_day_') !== false) {
                if ($value > 0) {
                    $profile_id = str_replace('post_per_day_', '', $key);
                    $number = $value + 1;
                    $interval = floor(24 / $number);
                    $schedules[$profile_id . '_schedule'] = [
                        'interval' => $interval * 60 * 60,
                        'display' => esc_html__('Only for profile' . $profile_id),
                    ];
                }
            }
        }

        return $schedules;
    }

    /**
     * Schedules the log cleanup event in the WordPress CRON on a daily basis
     *
     * @since   1.0.0
     */
    public function schedule_cron_event($type = 'daily_posts'): void
    {
        // Bail if the scheduled event already exists
        $general_settings = get_option('ecp_general_settings');
        if ($type !== 'daily_posts') {
            $next = $this->get_schedule_event_next_scheduled('Y-m-d H:i:s');
            if ($next !== false) {
                return;
            }

            // Schedule event
            if ($type === 'timestamp') {
                $scheduled_date_time = date('Y-m-d H:i:s', strtotime('+1 seconds'));
                wp_schedule_event(strtotime($scheduled_date_time), 'one_minute', 'wp_evergreen_content_schedule_cron_hook');
            } elseif ($type === 'empty_queue') {
                $scheduled_date_time = date('Y-m-d H:i:s', strtotime('+1 seconds'));
                wp_schedule_event(strtotime($scheduled_date_time), 'twice_hourly', 'wp_evergreen_content_schedule_cron_hook');
            }
        } else {
            $scheduled_date_time = date('Y-m-d H:i:s', strtotime('+1 seconds'));
            foreach ($general_settings as $key => $value) {
                if (stripos($key, 'post_per_day_') !== false) {
                    if ($value > 0) {
                        $profile_id = str_replace('post_per_day_', '', $key);
                        $next = $this->get_schedule_event_next_scheduled_profile($profile_id, 'Y-m-d H:i:s');
                        if ($next === false) {
                            wp_schedule_event(strtotime($scheduled_date_time), $profile_id . '_schedule', $profile_id . '_wp_evergreen_content_schedule_cron_hook');
                        }
                    }
                }
            }
        }
    }

    /**
     * Unschedules the log cleanup event in the WordPress CRON.
     *
     * @since   1.0.0
     */
    public function unschedule_cron_event(): void
    {
        wp_clear_scheduled_hook('wp_evergreen_content_schedule_cron_hook');

        $general_settings = get_option('ecp_general_settings');
        if (!empty($general_settings)) {
            foreach ($general_settings as $key => $value) {
                if (stripos($key, 'post_per_day_') !== false) {
                    $profile_id = str_replace('post_per_day_', '', $key);
                    wp_clear_scheduled_hook($profile_id . '_wp_evergreen_content_schedule_cron_hook');
                }
            }
        }
    }

    public function reschedule_cron_event($type = 'daily_posts'): void
    {
        $this->unschedule_cron_event();
        $this->schedule_cron_event($type);
    }

    /**
     * Reschedules the log cleanup event in the WordPress CRON, by unscheduling
     * and scheduling it.
     *
     * @since   1.0.0
     */
    public function reschedule_log_cleanup_event(): void
    {
        $this->unschedule_log_cleanup_event();
        $this->schedule_log_cleanup_event();
    }

    /**
     * Returns the scheduled log cleanup event, if it exists
     *
     * @since   1.0.0
     */
    public function get_schedule_cron_event()
    {
        return wp_get_schedule('wp_evergreen_content_schedule_cron_hook');
    }

    /**
     * Returns the scheduled log cleanup event's next date and time to run, if it exists
     *
     * @param mixed $format Format Timestamp (false | php date() compat. string)
     * @since   1.0.0
     */
    public function get_log_cleanup_event_next_scheduled($format = false)
    {
        // Get timestamp for when the event will next run
        $scheduled = wp_next_scheduled($this->base->plugin->filter_name . '_log_cleanup_cron');

        // If no timestamp or we're not formatting the result, return it now
        if (!$scheduled || !$format) {
            return $scheduled;
        }

        // Return formatted date/time
        return date($format, $scheduled);
    }

    public function get_schedule_event_next_scheduled($format = false)
    {
        // Get timestamp for when the event will next run
        $scheduled = wp_next_scheduled('wp_evergreen_content_schedule_cron_hook');

        // If no timestamp or we're not formatting the result, return it now
        if (!$scheduled || !$format) {
            return $scheduled;
        }

        // Return formatted date/time
        return date($format, $scheduled);
    }

    public function get_schedule_event_next_scheduled_profile($profile_id, $format = false)
    {
        // Get timestamp for when the event will next run
        $scheduled = wp_next_scheduled($profile_id .' _wp_evergreen_content_schedule_cron_hook');

        // If no timestamp or we're not formatting the result, return it now
        if (!$scheduled || !$format) {
            return $scheduled;
        }

        // Return formatted date/time
        return date($format, $scheduled);
    }

    public function get_schedule_single_event_next_scheduled($format = false)
    {
        // Get timestamp for when the event will next run
        $scheduled = wp_next_scheduled('wp_evergreen_content_schedule_single_cron_hook');

        // If no timestamp or we're not formatting the result, return it now
        if (!$scheduled || !$format) {
            return $scheduled;
        }

        // Return formatted date/time
        return date($format, $scheduled);
    }

    /**
     * Runs the schedule CRON event
     *
     * @since   1.0.0
     */
    public function run_schedule_cron(): void
    {
        $set = new Evergreen_Content_Poster_Settings(new Evergreen_Content_Poster_Buffer());

        $set->ajaxPostBufferData();
    }

    public function create_single_event_schedule($day, $time): void
    {
        $date_run_timestamp = $this->get_time_run_schedule($day, $time);

        // Schedule an event to run
        $next = $this->get_schedule_single_event_next_scheduled('Y-m-d H:i:s');
        if ($next !== false) {
            return;
        }

        // Schedule single event
        wp_schedule_single_event($date_run_timestamp, 'wp_evergreen_content_schedule_single_cron_hook');
    }

    /**
     * Figure out at which time and which day to run the cron
     *
     * @since   1.0.0
     */
    public function get_time_run_schedule($day, $time)
    {
        $arr_day = [
            '0' => 'sun',
            '1' => 'mon',
            '2' => 'tue',
            '3' => 'wed',
            '4' => 'thu',
            '5' => 'fri',
            '6' => 'sat',
        ];
        // Get today
        $setting = get_option('ecp_general_settings');
        if (isset($setting['eg_timezone']) && !is_null($setting['eg_timezone'])) {
            $time_zone = $setting['eg_timezone'];
        } else {
            $time_zone = 'UTC+0';
        }
        if (strpos($time_zone, 'UTC') !== false) {
            $time_zone = str_replace('UTC', '', $time_zone);
            $minute = $time_zone * 60;
            $today_now = date('Y-m-d H:i:s', strtotime($minute . ' minutes', strtotime(date('Y-m-d H:i:s'))));
            $date = date('Y-m-d', strtotime($minute . ' minutes', strtotime(date('Y-m-d H:i:s'))));
            $time_now = date('H:i', strtotime($minute . ' minutes', strtotime(date('Y-m-d H:i:s'))));
        } else {
            $today = new DateTime('now', new DateTimeZone($time_zone));
            $today_now = $today->format('Y-m-d H:i:s');
            $date = $today->format('Y-m-d');
            $time_now = $today->format('H:i');
        }

        $today_name = strtolower(date('D', strtotime($date)));
        $key_day = array_search($day, $arr_day);
        $key_today = array_search($today_name, $arr_day);
        $arr_time = explode(':', $time);
        $arr_time_now = explode(':', $time_now);
        if ($key_day > $key_today) {
            $temp_minute = ($key_day - $key_today) * 24 * 60 + ($arr_time[0] * 60 + $arr_time[1] - $arr_time_now[0] * 60 - $arr_time_now[1]);
        } elseif ($key_day === $key_today) {
            if ($time >= $time_now) {
                $temp_minute = ($key_day - $key_today) * 24 * 60 + ($arr_time[0] * 60 + $arr_time[1] - $arr_time_now[0] * 60 - $arr_time_now[1]);
            } else {
                $temp_minute = 7 * 24 * 60 + ($arr_time[0] * 60 + $arr_time[1] - $arr_time_now[0] * 60 - $arr_time_now[1]);
            }
        } else {
            $temp_minute = (7 - ($key_today - $key_day)) * 24 * 60 + ($arr_time[0] * 60 + $arr_time[1] - $arr_time_now[0] * 60 - $arr_time_now[1]);
        }

        return strtotime('+ ' . $temp_minute, strtotime($today_now));
    }
}
